@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: aggregation.c 2728 2016-12-18 17:49:20Z wkliao $ */
+/* $Id: aggregation.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -110,13 +110,9 @@
  *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NVARS 5
 
-#define ERR(e) {if((e)!=NC_NOERR)printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(e));}
+#define ERR(e) {if((e)!=NC_NOERR){printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(e));nerrs++;}}
 
 static int debug;
 
@@ -147,7 +143,7 @@ int benchmark_write(char       *filename,
                     MPI_Info   *w_info_used,
                     double     *timing)  /* [6] */
 {
-    int i, j, k, rank, nprocs, err, num_reqs;
+    int i, j, k, rank, nprocs, nerrs=0, err, num_reqs;
     int ncid, cmode, varid[NVARS], dimid[6], *reqs, *sts, psizes[2];
     void *buf[NVARS];
     double start_t, end_t;
@@ -348,7 +344,7 @@ int benchmark_write(char       *filename,
     free(reqs);
     for (i=0; i<NVARS; i++) free(buf[i]);
 
-    return 1;
+    return nerrs;
 }
 
 /*----< benchmark_read() >---------------------------------------------------*/
@@ -359,7 +355,7 @@ int benchmark_read(char       *filename,
                    MPI_Info   *r_info_used,
                    double     *timing)  /* [5] */
 {
-    int i, j, k, rank, nprocs, s_rank, err, num_reqs;
+    int i, j, k, rank, nprocs, s_rank, nerrs=0, err, num_reqs;
     int ncid, omode, varid[NVARS], *reqs, *sts, psizes[2];
     void *buf[NVARS];
     double start_t, end_t;
@@ -509,7 +505,7 @@ int benchmark_read(char       *filename,
     free(reqs);
     for (i=0; i<NVARS; i++) free(buf[i]);
 
-    return 1;
+    return nerrs;
 }
 
 static void
@@ -529,7 +525,7 @@ usage(char *argv0)
 int main(int argc, char** argv) {
     extern int optind;
     char filename[256];
-    int i, rank, nprocs, verbose=1;
+    int i, rank, nprocs, verbose=1, nerrs=0;
     double timing[11], max_t[11];
     MPI_Offset len, w_size=0, r_size=0, sum_w_size, sum_r_size;
     MPI_Comm comm=MPI_COMM_WORLD;
@@ -550,7 +546,7 @@ int main(int argc, char** argv) {
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -562,17 +558,12 @@ int main(int argc, char** argv) {
     if (argc > 1) snprintf(filename, 256, "%s", argv[1]);
     else          strcpy(filename, "testfile.nc");
 
-    benchmark_write(filename, len, &w_size, &w_info_used, timing);
-    benchmark_read (filename, len, &r_size, &r_info_used, timing+6);
+    nerrs += benchmark_write(filename, len, &w_size, &w_info_used, timing);
+    nerrs += benchmark_read (filename, len, &r_size, &r_info_used, timing+6);
 
     MPI_Reduce(&timing, &max_t,     11, MPI_DOUBLE, MPI_MAX, 0, comm);
-#ifdef MPI_OFFSET
     MPI_Reduce(&w_size, &sum_w_size, 1, MPI_OFFSET, MPI_SUM, 0, comm);
     MPI_Reduce(&r_size, &sum_r_size, 1, MPI_OFFSET, MPI_SUM, 0, comm);
-#else
-    MPI_Reduce(&w_size, &sum_w_size, 1, MPI_LONG_LONG, MPI_SUM, 0, comm);
-    MPI_Reduce(&r_size, &sum_r_size, 1, MPI_LONG_LONG, MPI_SUM, 0, comm);
-#endif
     if (verbose && rank == 0) {
         double bw = sum_w_size;
         bw /= 1048576.0;
@@ -624,6 +615,6 @@ int main(int argc, char** argv) {
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
