@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: block_cyclic.c 2728 2016-12-18 17:49:20Z wkliao $ */
+/* $Id: block_cyclic.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * This example, generalized from column_wise.c, makes a number of nonblocking
@@ -74,10 +74,6 @@
 #include <mpi.h>
 #include <pnetcdf.h>
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NY 10
 #define NX 4
 
@@ -85,7 +81,7 @@
 #define MIN(a,b) (((a)<(b))?(a):(b))
 #endif
 
-#define ERR {if(err!=NC_NOERR){printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));nerrs++;}}
+#define ERR {if(err!=NC_NOERR){printf("Error at line %d in %s: %s\n", __LINE__,__FILE__, ncmpi_strerror(err));nerrs++;}}
 
 static void
 usage(char *argv0)
@@ -119,7 +115,7 @@ int main(int argc, char** argv) {
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -206,8 +202,8 @@ int main(int argc, char** argv) {
     /* check status of all requests */
     for (i=0; i<num_reqs; i++)
         if (sts[i] != NC_NOERR)
-            printf("Error: nonblocking write fails on request %d (%s)\n",
-                   i, ncmpi_strerror(sts[i]));
+            printf("Error at line %d in %s: nonblocking write fails on request %d (%s)\n",
+                   __LINE__,__FILE__,i, ncmpi_strerror(sts[i]));
 
     err = ncmpi_close(ncid);
     ERR
@@ -280,8 +276,8 @@ int main(int argc, char** argv) {
     /* check status of all requests */
     for (i=0; i<num_reqs; i++)
         if (sts[i] != NC_NOERR)
-            printf("Error: nonblocking read fails on request %d (%s)\n",
-                   i, ncmpi_strerror(sts[i]));
+            printf("Error at line %d in %s: nonblocking read fails on request %d (%s)\n",
+                   __LINE__,__FILE__,i, ncmpi_strerror(sts[i]));
 
     err = ncmpi_close(ncid);
     ERR
@@ -310,6 +306,6 @@ int main(int argc, char** argv) {
     }
 
     MPI_Finalize();
-    return nerrs;
+    return (nerrs > 0);
 }
 
