@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: flexible_api.c 2717 2016-12-18 01:20:47Z wkliao $ */
+/* $Id: flexible_api.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -78,15 +78,11 @@
 #include <mpi.h>
 #include <pnetcdf.h>
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NZ 5
 #define NY 5
 #define NX 5
 
-#define ERR {if(err!=NC_NOERR){printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));nerrs++;}}
+#define ERR {if(err!=NC_NOERR){printf("Error at line %d in %s: %s\n", __LINE__,__FILE__, ncmpi_strerror(err));nerrs++;}}
 
 static void
 usage(char *argv0)
@@ -122,7 +118,7 @@ int main(int argc, char** argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -171,7 +167,8 @@ int main(int argc, char** argv)
     /* check the contents of put buffer */
     for (i=0; i<buffer_len; i++) {
         if (buf_zy[i] != rank)
-            printf("Error put buffer[%d] is altered\n",i);
+            printf("Error at line %d in %s: put buffer[%d] is altered\n",
+            __LINE__,__FILE__,i);
     }
 
     for (i=0; i<buffer_len; i++) buf_zy[i] = -1;
@@ -227,7 +224,8 @@ int main(int argc, char** argv)
     /* check the contents of put buffer */
     for (i=0; i<buffer_len; i++) {
         if (buf_yx[i] != rank)
-            printf("Error iput buffer[%d]=%f is altered\n",i,buf_yx[i]);
+            printf("Error at line %d in %s: iput buffer[%d]=%f is altered\n",
+            __LINE__,__FILE__,i,buf_yx[i]);
     }
 
     for (i=0; i<buffer_len; i++) buf_yx[i] = -1;
@@ -271,6 +269,6 @@ int main(int argc, char** argv)
     }
 
     MPI_Finalize();
-    return nerrs;
+    return (nerrs > 0);
 }
 
