@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: nonblocking_write.c 2717 2016-12-18 01:20:47Z wkliao $ */
+/* $Id: nonblocking_write.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /*    This example is similar to collective_write.c but using nonblocking APIs.
  *    It creates a netcdf file in CD-5 format and writes a number of
@@ -39,14 +39,10 @@
 #include <mpi.h>
 #include <pnetcdf.h>
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NDIMS    3
 #define NUM_VARS 10
 
-#define ERR {if(err!=NC_NOERR){printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));nerrs++;}}
+#define ERR {if(err!=NC_NOERR){printf("Error at line %d in %s: %s\n", __LINE__,__FILE__, ncmpi_strerror(err));nerrs++;}}
 
 static void
 usage(char *argv0)
@@ -110,7 +106,7 @@ int main(int argc, char **argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -154,7 +150,8 @@ int main(int argc, char **argv)
     err = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER|NC_64BIT_DATA,
                        info, &ncid);
     if (err != NC_NOERR) {
-        printf("Error: ncmpi_create() file %s (%s)\n",filename,ncmpi_strerror(err));
+        printf("Error at line %d in %s: ncmpi_create() file %s (%s)\n",
+        __LINE__,__FILE__,filename,ncmpi_strerror(err));
         MPI_Abort(MPI_COMM_WORLD, -1);
         exit(1);
     }
@@ -194,8 +191,8 @@ int main(int argc, char **argv)
     ERR
     for (i=0; i<NUM_VARS; i++) {
         if (st[i] != NC_NOERR)
-            printf("Error: nonblocking write fails on request %d (%s)\n",
-                   i, ncmpi_strerror(st[i]));
+            printf("Error at line %d in %s: nonblocking write fails on request %d (%s)\n",
+            __LINE__,__FILE__,i, ncmpi_strerror(st[i]));
     }
 
     /* write one variable at a time using bput */
@@ -216,8 +213,8 @@ int main(int argc, char **argv)
     ERR
     for (i=0; i<NUM_VARS; i++) {
         if (st[i] != NC_NOERR)
-            printf("Error: nonblocking write fails on request %d (%s)\n",
-                   i, ncmpi_strerror(st[i]));
+            printf("Error at line %d in %s: nonblocking write fails on request %d (%s)\n",
+            __LINE__,__FILE__,i, ncmpi_strerror(st[i]));
     }
 
     /* detach the temporary buffer */
@@ -271,6 +268,6 @@ int main(int argc, char **argv)
     }
 
     MPI_Finalize();
-    return nerrs;
+    return (nerrs > 0);
 }
 
