@@ -57,14 +57,10 @@
 #include <mpi.h>
 #include <pnetcdf.h>
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NY 10
 #define NX 4
 
-#define ERR {if(err!=NC_NOERR){printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));nerrs++;}}
+#define ERR {if(err!=NC_NOERR){printf("Error at line %d in %s: %s\n", __LINE__,__FILE__, ncmpi_strerror(err));nerrs++;}}
 
 static void
 usage(char *argv0)
@@ -98,7 +94,7 @@ int main(int argc, char** argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -111,8 +107,7 @@ int main(int argc, char** argv)
     MPI_Info_set(info, "nc_var_align_size", "1");
 
     cmode = NC_CLOBBER;
-    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, info, &ncid);
-    ERR
+    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, info, &ncid); ERR
 
     MPI_Info_free(&info);
 
@@ -122,14 +117,10 @@ int main(int argc, char** argv)
     myNX  = NX;
     if (verbose) printf("%2d: myOff=%3d myNX=%3d\n",rank,myOff,myNX);
 
-    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]);
-    ERR
-    err = ncmpi_def_dim(ncid, "X", G_NX, &dimid[1]);
-    ERR
-    err = ncmpi_def_var(ncid, "var", NC_INT, 2, dimid, &varid);
-    ERR
-    err = ncmpi_enddef(ncid);
-    ERR
+    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); ERR
+    err = ncmpi_def_dim(ncid, "X", G_NX, &dimid[1]); ERR
+    err = ncmpi_def_var(ncid, "var", NC_INT, 2, dimid, &varid); ERR
+    err = ncmpi_enddef(ncid); ERR
 
     /* initialize the buffer with rank ID */
     buf = (int**) malloc(myNX * sizeof(int*));
@@ -150,10 +141,15 @@ int main(int argc, char** argv)
         ERR
         start[1] += nprocs;
     }
-    err = ncmpi_wait_all(ncid, NC_REQ_ALL, NULL, NULL);
-    ERR
+    err = ncmpi_wait_all(ncid, NC_REQ_ALL, NULL, NULL); ERR
+
+    err = ncmpi_close(ncid); ERR
 
     /* read back using the same access pattern */
+    err = ncmpi_open(MPI_COMM_WORLD, filename, NC_NOWRITE, info, &ncid); ERR
+
+    err = ncmpi_inq_varid(ncid, "var", &varid); ERR
+
     for (i=0; i<myNX; i++)
         for (j=0; j<NY; j++) buf[i][j] = -1;
 
@@ -166,18 +162,17 @@ int main(int argc, char** argv)
         ERR
         start[1] += nprocs;
     }
-    err = ncmpi_wait_all(ncid, NC_REQ_ALL, NULL, NULL);
-    ERR
+    err = ncmpi_wait_all(ncid, NC_REQ_ALL, NULL, NULL); ERR
 
     /* check contents of read data of all requests */
     for (i=0; i<myNX; i++) {
         for (j=0; j<NY; j++)
             if (buf[i][j] != rank)
-                printf("Error: expect buf[%d][%d]=%d but got %d\n",i,j,rank,buf[i][j]);
+                printf("Error at line %d in %s: expect buf[%d][%d]=%d but got %d\n",
+                __LINE__,__FILE__,i,j,rank,buf[i][j]);
     }
 
-    err = ncmpi_close(ncid);
-    ERR
+    err = ncmpi_close(ncid); ERR
 
     for (i=0; i<myNX; i++) free(buf[i]);
     free(buf);
@@ -193,6 +188,6 @@ int main(int argc, char** argv)
     }
 
     MPI_Finalize();
-    return nerrs;
+    return (nerrs > 0);
 }
 
