@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: collective_write.cpp 2717 2016-12-18 01:20:47Z wkliao $ */
+/* $Id: collective_write.cpp 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /*
  *    This example mimics the coll_perf.c from ROMIO.
@@ -46,10 +46,6 @@ using namespace std;
 using namespace PnetCDF;
 using namespace PnetCDF::exceptions;
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NDIMS    3
 #define NUM_VARS 10
 
@@ -114,7 +110,7 @@ int main(int argc, char **argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
