@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: fill_mode.cpp 2728 2016-12-18 17:49:20Z wkliao $ */
+/* $Id: fill_mode.cpp 3589 2017-12-12 06:33:02Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * This example shows how to use 
@@ -72,10 +72,6 @@ using namespace std;
 using namespace PnetCDF;
 using namespace PnetCDF::exceptions;
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NY 3
 #define NX 4
 
@@ -109,7 +105,7 @@ int main(int argc, char** argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -178,7 +174,7 @@ int main(int argc, char** argv)
         if (!fillMode)
             printf("Error: expecting fillMode to be false\n");
         if (fill_value != NC_FILL_INT)
-            printf("Error: expecting fillMode to be %ld but got %d\n",NC_FILL_INT,fill_value);
+            printf("Error: expecting fillMode to be %d but got %d\n",NC_FILL_INT,fill_value);
 
         /* fill the 1st record of the record variable */
         start[0] = 0;
@@ -199,6 +195,7 @@ int main(int argc, char** argv)
     }
     catch(NcmpiException& e) {
        cout << e.what() << " error code=" << e.errorCode() << " Error!\n";
+       return 1;
     }
 
     /* check if there is any PnetCDF internal malloc residue */
