@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: get_info.cpp 2728 2016-12-18 17:49:20Z wkliao $ */
+/* $Id: get_info.cpp 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /*
  *    prints all MPI-IO hints used
@@ -49,10 +49,6 @@ using namespace std;
 using namespace PnetCDF;
 using namespace PnetCDF::exceptions;
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 static void
 usage(char *argv0)
 {
@@ -102,7 +98,7 @@ int main(int argc, char **argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
