@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: get_vara.cpp 2728 2016-12-18 17:49:20Z wkliao $ */
+/* $Id: get_vara.cpp 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * This example is the read counterpart of example put_vara.cpp. It shows how to
@@ -66,10 +66,6 @@ using namespace std;
 using namespace PnetCDF;
 using namespace PnetCDF::exceptions;
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 static void
 usage(char *argv0)
 {
@@ -100,7 +96,7 @@ int main(int argc, char** argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -176,6 +172,7 @@ int main(int argc, char** argv)
     }
     catch(NcmpiException& e) {
        cout << e.what() << " error code=" << e.errorCode() << " Error!\n";
+       return 1;
     }
 
     /* check if there is any PnetCDF internal malloc residue */
