@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: put_varn_int.cpp 2728 2016-12-18 17:49:20Z wkliao $ */
+/* $Id: put_varn_int.cpp 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * This example shows how to use a single call of NcmpiVar::putVarn_all() to
@@ -54,10 +54,6 @@ using namespace std;
 using namespace PnetCDF;
 using namespace PnetCDF::exceptions;
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NY 4
 #define NX 10
 #define NDIMS 2
@@ -93,7 +89,7 @@ int main(int argc, char** argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -213,6 +209,7 @@ int main(int argc, char** argv)
     }
     catch(NcmpiException& e) {
        cout << e.what() << " error code=" << e.errorCode() << " Error!\n";
+       return 1;
     }
 
     /* check if there is any PnetCDF internal malloc residue */
