@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: transpose.cpp 2728 2016-12-18 17:49:20Z wkliao $ */
+/* $Id: transpose.cpp 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /*
  *    This example shows how to use varm API to write six 3D integer array
@@ -42,10 +42,6 @@ using namespace std;
 using namespace PnetCDF;
 using namespace PnetCDF::exceptions;
 
-#ifndef MPI_OFFSET
-#define MPI_OFFSET MPI_LONG_LONG_INT
-#endif
-
 #define NDIMS 3
 
 #define HANDLE_ERROR {                                \
@@ -89,7 +85,7 @@ int main(int argc, char **argv)
             case 'h':
             default:  if (rank==0) usage(argv[0]);
                       MPI_Finalize();
-                      return 0;
+                      return 1;
         }
     argc -= optind;
     argv += optind;
@@ -222,6 +218,7 @@ int main(int argc, char **argv)
     }
     catch(NcmpiException& e) {
        cout << e.what() << " error code=" << e.errorCode() << " Error!\n";
+       return 1;
     }
 
     free(buf);
