@@ -2,7 +2,7 @@
 !   Copyright (C) 2015, Northwestern University
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: fill_mode.f 2476 2016-09-06 01:05:33Z wkliao $
+! $Id: fill_mode.f 3341 2017-08-25 22:29:08Z wkliao $
 
 !
 ! This example shows how to use
@@ -179,11 +179,15 @@
           call check(err, 'In nfmpi_put_vara_int_all: ')
 
           err = nfmpi_inq_var_fill(ncid, fix_varid, no_fill, fill_value)
-          if (no_fill .NE. 0)
-     +        print*,"Error: expecting no_fill to be 0"
-          if (fill_value .NE. NF_FILL_INT)
-     +        print*,"Error: expecting no_fill to be ",NF_FILL_INT,
+          if (no_fill .NE. 0) then
+              print*,"Error: expecting no_fill to be 0"
+              stop 2
+          endif
+          if (fill_value .NE. NF_FILL_INT) then
+              print*,"Error: expecting no_fill to be ",NF_FILL_INT,
      +               " but got ", fill_value
+              stop 2
+          endif
 
           ! fill the 1st record of the record variable
           starts(2) = 1
@@ -204,6 +208,7 @@
           ! write to the 2nd record
           err = nfmpi_put_vara_int_all(ncid, rec_varid, starts, counts,
      +                                 buf)
+          call check(err, 'In nfmpi_put_vara_int_all: ')
 
           ! close the file
           err = nfmpi_close(ncid)
