@@ -3,7 +3,7 @@
 !  Laboratory
 !  See COPYRIGHT notice in top-level directory.
 !
-! $Id: get_info.f 2476 2016-09-06 01:05:33Z wkliao $
+! $Id: get_info.f 3507 2017-11-10 00:51:32Z wkliao $
 
 !
 !    To compile:
@@ -63,9 +63,9 @@
         call MPI_Bcast(filename, 256, MPI_CHARACTER, 0,
      +                 MPI_COMM_WORLD, err)
 
-        omode = NF_NOWRITE + NF_64BIT_OFFSET
-        err = nfmpi_open(MPI_COMM_WORLD, filename, omode,
-     +                    MPI_INFO_NULL, ncid)
+        omode = NF_CLOBBER + NF_64BIT_OFFSET
+        err = nfmpi_create(MPI_COMM_WORLD, filename, omode,
+     +                     MPI_INFO_NULL, ncid)
         if (err .ne. NF_NOERR) call handle_err('nfmpi_open',err)
 
 
