@@ -2,7 +2,7 @@
 !   Copyright (C) 2014, Northwestern University
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: i_varn_real.f 2325 2016-02-28 07:49:13Z wkliao $
+! $Id: i_varn_real.f 2476 2016-09-06 01:05:33Z wkliao $
 
 ! This example tests nonblocking varn API, nfmpi_iput_varn_real()
 ! It writes a sequence of requests with arbitrary array indices and
@@ -103,7 +103,7 @@
           integer*8 NX, NY
           PARAMETER(NDIMS=2, NX=4, NY=10)
 
-          character*128 filename, cmd
+          character*256 filename, cmd
           integer i, j, n, err, ierr, nprocs, rank, get_args
           integer cmode, ncid, varid(4), dimid(NDIMS), nreqs
           integer reqs(4), sts(4), num_segs(4)
@@ -139,7 +139,7 @@
      +               '4 processes'
 
           ! set an MPI-IO hint to disable file offset alignment for
-          ! fix-sized variables
+          ! fixed-size variables
           call MPI_Info_create(info, err)
           call MPI_Info_set(info, "nc_var_align_size", "1", err)
 
@@ -316,7 +316,7 @@
  998      format(A,I13,A)
           err = nfmpi_inq_malloc_size(malloc_size)
           if (err .EQ. NF_NOERR) then
-              call MPI_Reduce(malloc_size, sum_size, 1, MPI_OFFSET,
+              call MPI_Reduce(malloc_size, sum_size, 1, MPI_INTEGER8,
      +                        MPI_SUM, 0, MPI_COMM_WORLD, err)
               if (rank .EQ. 0 .AND. sum_size .GT. 0)
      +            print 998,
