@@ -2,7 +2,7 @@
 !   Copyright (C) 2015, Northwestern University and Argonne National Laboratory
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: fill_mode.f90 2476 2016-09-06 01:05:33Z wkliao $
+! $Id: fill_mode.f90 3341 2017-08-25 22:29:08Z wkliao $
 
 ! This example shows how to use
 ! 1. nf90mpi_set_fill() to enable fill mode
@@ -172,11 +172,15 @@
           call check(err, 'In nf90mpi_put_var_all: ')
 
           err = nf90mpi_inq_var_fill(ncid, fix_varid, no_fill, fill_value)
-          if (no_fill .NE. 0) &
+          if (no_fill .NE. 0) then
               print*,"Error: expecting no_fill to be 0"
-          if (fill_value .NE. NF90_FILL_INT) &
+              stop 2
+          endif
+          if (fill_value .NE. NF90_FILL_INT) then
               print*,"Error: expecting no_fill to be ",NF90_FILL_INT, &
                      " but got ", fill_value
+              stop 2
+          endif
 
           ! fill the 1st record of the record variable
           starts(2) = 1
