@@ -2,7 +2,7 @@
 !  Copyright (C) 2012, Northwestern University and Argonne National Laboratory
 !  See COPYRIGHT notice in top-level directory.
 !
-! $Id: nonblocking_write.f90 2325 2016-02-28 07:49:13Z wkliao $
+! $Id: nonblocking_write.f90 2476 2016-09-06 01:05:33Z wkliao $
 
 !    This example is the Fortran 90 version of nonblocking_write.c
 !    It creates a netcdf file in CD-5 format and writes a number of
@@ -101,7 +101,7 @@
           enddo
 
           ! set an MPI-IO hint to disable file offset alignment for
-          ! fix-sized variables
+          ! fixed-size variables
           call MPI_Info_create(info, err)
           call MPI_Info_set(info, "nc_var_align_size", "1", err)
 
@@ -190,7 +190,7 @@
  998      format(A,I13,A)
           err = nf90mpi_inq_malloc_size(malloc_size)
           if (err == NF90_NOERR) then
-              call MPI_Reduce(malloc_size, sum_size, 1, MPI_OFFSET, &
+              call MPI_Reduce(malloc_size, sum_size, 1, MPI_INTEGER8, &
                               MPI_SUM, 0, MPI_COMM_WORLD, err)
               if (rank .EQ. 0 .AND. sum_size .GT. 0_MPI_OFFSET_KIND) print 998, &
                   'heap memory allocated by PnetCDF internally has ',  &
