@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: pnetcdf-write-from-master.c 2640 2016-11-18 21:08:08Z wkliao $ */
+/* $Id: pnetcdf-write-from-master.c 3511 2017-11-10 01:03:16Z wkliao $ */
 
 /* simple demonstration of pnetcdf 
  * text attribute on dataset
@@ -36,21 +36,21 @@
     }
 */
 
+#include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <mpi.h>
 #include <pnetcdf.h>
-#include <stdio.h>
 
 static void handle_error(int status, int lineno)
 {
-    fprintf(stderr, "Error at line %d: %s\n", lineno, ncmpi_strerror(status));
+    fprintf(stderr, "Error at line %d of %s: %s\n", lineno, __FILE__, ncmpi_strerror(status));
     MPI_Abort(MPI_COMM_WORLD, 1);
 }
 
 int main(int argc, char **argv) {
     int ret, ncid=0, nprocs, rank, dimid, varid1=0, varid2=0, ndims=1;
-    MPI_Offset start, count=1;
-    char buf[13] = "Hello World\n";
+    char filename[256], buf[13] = "Hello World\n";
     int *data=NULL;
 
     MPI_Init(&argc, &argv);
@@ -58,14 +58,16 @@ int main(int argc, char **argv) {
     MPI_Comm_rank(MPI_COMM_WORLD, &rank);
     MPI_Comm_size(MPI_COMM_WORLD, &nprocs);
 
-    if (argc != 2) {
+    if (argc > 2) {
         if (rank == 0) printf("Usage: %s filename\n", argv[0]);
         MPI_Finalize();
         exit(-1);
     }
+    if (argc > 1) snprintf(filename, 256, "%s", argv[1]);
+    else          strcpy(filename, "testfile.nc");
 
     if (rank == 0) {
-        ret = ncmpi_create(MPI_COMM_SELF, argv[1],
+        ret = ncmpi_create(MPI_COMM_SELF, filename,
                            NC_CLOBBER|NC_64BIT_OFFSET, MPI_INFO_NULL, &ncid);
         if (ret != NC_NOERR) handle_error(ret, __LINE__);
 
@@ -99,11 +101,12 @@ int main(int argc, char **argv) {
          * happens from a single processor.  This approach can be ok if the
          * amount of data is quite small, but almost always the underlying
          * MPI-IO library can do a better job */
-        start=0, count=nprocs;
-        ret = ncmpi_put_vara_int_all(ncid, varid1, &start, &count, data);
+        MPI_Offset start[1], count[1];
+        start[0]=0, count[0]=nprocs;
+        ret = ncmpi_put_vara_int_all(ncid, varid1, start, count, data);
         if (ret != NC_NOERR) handle_error(ret, __LINE__);
 
-        ret = ncmpi_put_vara_int_all(ncid, varid2, &start, &count, data);
+        ret = ncmpi_put_vara_int_all(ncid, varid2, start, count, data);
         if (ret != NC_NOERR) handle_error(ret, __LINE__);
 
         ret = ncmpi_close(ncid);
