@@ -2,7 +2,7 @@
  *  Copyright (C) 2010, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: ncmpidiff.c 2731 2016-12-19 01:49:08Z wkliao $ */
+/* $Id: ncmpidiff.c 3359 2017-09-10 18:29:10Z wkliao $ */
 
 /* wkliao: This diff utility compares header and variables of two files
  *         regardless the define order of the variables and attributes.
@@ -17,8 +17,8 @@
  *           mpiexec -n 8 ncmpidiff -h -v var1,var2 file1.nc file2.nc
  */
 
-#if HAVE_CONFIG_H
-# include <ncconfig.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
 #endif
 
 #include <stdarg.h>
@@ -61,7 +61,8 @@
 }
 
 #define CHECK_GLOBAL_ATT_DIFF(type, func, nctype) {                    \
-    int   pos, len = attlen1 * sizeof(type);                           \
+    int pos;                                                           \
+    size_t len = (size_t)attlen1 * sizeof(type);                       \
     type *b1 = (type *)malloc(len);                                    \
     if (!b1) OOM_ERROR                                                 \
     type *b2 = (type *)malloc(len);                                    \
@@ -83,7 +84,8 @@
 }
 
 #define CHECK_VAR_ATT_DIFF(type, func, nctype) {                              \
-    int   pos, len = attlen1 * sizeof(type);                                  \
+    int pos;                                                                  \
+    size_t len = (size_t)attlen1 * sizeof(type);                              \
     type *b1 = (type *)malloc(len);                                           \
     if (!b1) OOM_ERROR                                                        \
     type *b2 = (type *)malloc(len);                                           \
@@ -105,7 +107,8 @@
 }
 
 #define CHECK_VAR_DIFF(type, func, nctype) {                                 \
-    int   pos, isDiff, len = varsize * sizeof(type);                         \
+    int pos, isDiff;                                                         \
+    size_t len = (size_t)varsize * sizeof(type);                             \
     type *b1 = (type *)malloc(len);                                          \
     if (!b1) OOM_ERROR                                                       \
     type *b2 = (type *)malloc(len);                                          \
@@ -134,6 +137,7 @@ char *progname;
 #define EXIT_SUCCESS 0
 #define EXIT_FAILURE 1
 #else
+/* In OpenVMS, success is indicated by odd values and failure by even values. */
 #define EXIT_SUCCESS 1
 #define EXIT_FAILURE 0
 #endif
@@ -197,7 +201,7 @@ get_var_names(char *optarg, struct vspec* vspecp)
         if (*cp == ',')
             nvars++;
 
-    vspecp->names = (char **) malloc(nvars * sizeof(char*));
+    vspecp->names = (char **) malloc((size_t)nvars * sizeof(char*));
     if (!vspecp->names) OOM_ERROR
 
     cpp = vspecp->names;
@@ -240,7 +244,7 @@ int main(int argc, char **argv)
     int ncid1, ndims1, nvars1, natts1, unlimdimid1, *dimids1;
     int ncid2, ndims2, nvars2, natts2, unlimdimid2, *dimids2;
     char *name1, *name2;
-    MPI_Offset *shape, varsize, *start;
+    MPI_Offset *shape=NULL, varsize, *start=NULL;
     MPI_Offset attlen1, dimlen1, attlen2, dimlen2;
     nc_type type1, type2;
     MPI_Comm comm=MPI_COMM_WORLD;
@@ -295,18 +299,10 @@ int main(int argc, char **argv)
         check_header      = 1;
     }
 
-    dimids1 = (int*) malloc(NC_MAX_DIMS * sizeof(int));
-    if (!dimids1) OOM_ERROR
-    dimids2 = (int*) malloc(NC_MAX_DIMS * sizeof(int));
-    if (!dimids2) OOM_ERROR
     name1   = (char*) malloc(NC_MAX_NAME);
     if (!name1) OOM_ERROR
     name2   = (char*) malloc(NC_MAX_NAME);
     if (!name2) OOM_ERROR
-    shape   = (MPI_Offset*) malloc(NC_MAX_VAR_DIMS * sizeof(MPI_Offset));
-    if (!shape) OOM_ERROR
-    start   = (MPI_Offset*) malloc(NC_MAX_VAR_DIMS * sizeof(MPI_Offset));
-    if (!start) OOM_ERROR
 
     /* Nov. 18, 2014 -- disable subfiling as it does not correctly handle the
      * cases when  nprocs < num_subfiles */
@@ -378,12 +374,12 @@ int main(int argc, char **argv)
 
             if (attlen1 != attlen2) {
                 if (!quiet) printf("DIFF: global attribute \"%s\" length (%lld) != (%lld)\n",
-                       name1,(long long int)attlen1,(long long int)attlen2);
+                       name1,attlen1,attlen2);
                 numHeadDIFF++;
                 continue;
             }
             else if (verbose)
-                printf("\tSAME: length (%lld)\n",(long long int)attlen1);
+                printf("\tSAME: length (%lld)\n",attlen1);
 
             switch (type1) {
                 case NC_CHAR:   CHECK_GLOBAL_ATT_DIFF(char,   ncmpi_get_att_text,      NC_CHAR)
@@ -454,6 +450,9 @@ int main(int argc, char **argv)
         /* Compare variables' metadata */
         for (i=0; i<nvars1; i++) {
             int varid;
+            err = ncmpi_inq_varndims(ncid1, i, &ndims1); HANDLE_ERROR
+            dimids1 = (int*) malloc((size_t)ndims1 * SIZEOF_INT);
+            if (!dimids1) OOM_ERROR
             err = ncmpi_inq_var(ncid1, i, name1, &type1, &ndims1, dimids1, &natts1);
             HANDLE_ERROR
             /* find the variable with the same name from ncid2 */
@@ -465,6 +464,9 @@ int main(int argc, char **argv)
                 numVarDIFF++;
                 continue;
             }
+            err = ncmpi_inq_varndims(ncid2, varid, &ndims2); HANDLE_ERROR
+            dimids2 = (int*) malloc((size_t)ndims2 * SIZEOF_INT);
+            if (!dimids2) OOM_ERROR
             err = ncmpi_inq_var(ncid2, varid, name2, &type2, &ndims2, dimids2, &natts2);
             HANDLE_ERROR
 
@@ -582,6 +584,8 @@ int main(int argc, char **argv)
                     numHeadDIFF++;
                 }
             }
+            free(dimids1);
+            free(dimids2);
         }
         for (i=0; i<nvars2; i++) { /* check variables in file2 but not in file1 */
             int varid;
@@ -599,15 +603,13 @@ int main(int argc, char **argv)
     }
 
     /* compare variable contents */
-    for (i=0; i<NC_MAX_VAR_DIMS; i++) start[i] = 0;
-
     nvars = 0;
     if (check_variable_list) nvars = var_list.nvars;
 
     if (check_entire_file) { /* header has been checked */
         ncmpi_inq_nvars(ncid1, &nvars);
         var_list.nvars = nvars;
-        var_list.names = (char**) malloc(nvars * sizeof(char*));
+        var_list.names = (char**) malloc((size_t)nvars * sizeof(char*));
         if (!var_list.names) OOM_ERROR
         /* get all the variable names from file1 */
         for (i=0; i<nvars; i++) {
@@ -640,8 +642,14 @@ int main(int argc, char **argv)
             }
             continue;
         }
+        err = ncmpi_inq_varndims(ncid1, varid1, &ndims1); HANDLE_ERROR
+        dimids1 = (int*) malloc((size_t)ndims1 * SIZEOF_INT);
+        if (!dimids1) OOM_ERROR
         err = ncmpi_inq_var(ncid1, varid1, name1, &type1, &ndims1, dimids1, &natts1);
         HANDLE_ERROR
+        err = ncmpi_inq_varndims(ncid2, varid2, &ndims2); HANDLE_ERROR
+        dimids2 = (int*) malloc((size_t)ndims2 * SIZEOF_INT);
+        if (!dimids2) OOM_ERROR
         err = ncmpi_inq_var(ncid2, varid2, name2, &type2, &ndims2, dimids2, &natts2);
         HANDLE_ERROR
 
@@ -675,6 +683,10 @@ int main(int argc, char **argv)
         else if (!check_header && !rank && verbose)
             printf("\tSAME: number of dimensions (%d)\n",ndims1);
 
+        shape = (MPI_Offset*) calloc((size_t)ndims1 * 2, SIZEOF_MPI_OFFSET);
+        if (!shape) OOM_ERROR
+        start = shape + ndims1;
+
         /* check dimension length only */
         for (j=0; j<ndims1; j++) { /* check variable's dimensionality */
             err = ncmpi_inq_dimlen(ncid1, dimids1[j], &dimlen1);
@@ -700,13 +712,31 @@ int main(int argc, char **argv)
         if (j != ndims1)
             continue; /* skip this variable */
 
-        varsize  = 1;
+        if (dimids1[0] == unlimdimid1) { /* record variable */
+            err = ncmpi_inq_dimlen(ncid1, unlimdimid1, &shape[0]);
+            HANDLE_ERROR
+        }
+
+        for (j=0; j<ndims1; j++) {
+            if (shape[j] >= nprocs) { /* partition along dimension j among processes */
+                MPI_Offset dimLen = shape[j];
+                shape[j] = dimLen / nprocs;
+                start[j] = shape[j] * rank;
+                if (rank < dimLen % nprocs) {
+                    start[j] += rank;
+                    shape[j]++;
+                }
+                else
+                    start[j] += dimLen % nprocs;
+                break;
+            }
+        }
+        /* if none of shape[*] >= nprocs, then let all processes compare the
+         * whole variable */
+
+        varsize = 1;
         /* block partition the variable along the 1st dimension */
         for (j=0; j<ndims1; j++) {
-            if (j == 0) {
-                shape[j] /= nprocs;
-                start[j] = shape[j] * rank;
-            }
             varsize *= shape[j];
         }
  
@@ -724,6 +754,9 @@ int main(int argc, char **argv)
             case NC_UINT64: CHECK_VAR_DIFF(uint64, ncmpi_get_vara_ulonglong_all, NC_UINT64)
             default: ; /* TODO: handle unexpected types */
         }
+        free(shape);
+        free(dimids1);
+        free(dimids2);
     }
 
     /* close files */
@@ -734,25 +767,22 @@ int main(int argc, char **argv)
 
     /* summary of the difference */
     MPI_Reduce(&numVarDIFF, &varDIFF, 1, MPI_LONG_LONG_INT, MPI_SUM, 0, comm);
-    if (rank == 0) {
+    if (rank == 0 && !quiet) {
         if (check_header) {
-            if (numHeadDIFF == 0) {
-                if (!quiet) printf("Headers of two files are the same\n");
-            }
+            if (numHeadDIFF == 0)
+                printf("Headers of two files are the same\n");
             else
                 printf("Number of differences in header %lld\n",numHeadDIFF);
         }
         if (check_variable_list) {
-            if (varDIFF == 0) {
-                if (!quiet) printf("Compared variable(s) are the same\n");
-            }
+            if (varDIFF == 0)
+                printf("Compared variable(s) are the same\n");
             else
                 printf("Compared variables(s) has %lld differences\n",varDIFF);
         }
         if (check_entire_file) {
-            if (varDIFF == 0) {
-                if (!quiet) printf("All variables of two files are the same\n");
-            }
+            if (varDIFF == 0)
+                printf("All variables of two files are the same\n");
             else
                 printf("Number of differences in variables %lld\n",varDIFF);
         }
@@ -764,22 +794,12 @@ int main(int argc, char **argv)
             free(var_list.names[i]);
         free(var_list.names);
     }
-    free(dimids1);
-    free(dimids2);
     free(name1);
     free(name2);
-    free(shape);
-    free(start);
 
     if (rank == 0) numDIFF = varDIFF + numHeadDIFF;
     MPI_Bcast(&numDIFF, 1, MPI_LONG_LONG_INT, 0, comm);
 
     MPI_Finalize();
-#ifdef vms
-    if (quiet) exit((numDIFF == 0) ? 0 : 1);
-    else       exit(EXIT_SUCCESS);
-#else
-    if (quiet) return ((numDIFF == 0) ? 0 : 1);
-    else       return EXIT_SUCCESS;
-#endif
+    exit((numDIFF == 0) ? EXIT_SUCCESS : EXIT_FAILURE);
 }
