@@ -3,10 +3,10 @@
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
  *   $Header$
  *********************************************************************/
-/* $Id: vardata.c 2322 2016-02-26 22:47:06Z wkliao $ */
+/* $Id: vardata.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
-#if HAVE_CONFIG_H
-# include <ncconfig.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
 #endif
 #include <stdio.h>
 #include <ctype.h>
@@ -298,14 +298,14 @@ annotate(
       case LANG_C:
 	/* C variable indices */
 	for (id = 0; id < vrank-1; id++)
-	  Printf("%lu,", (unsigned long) cor[id]);
-	Printf("%lu", (unsigned long) cor[id] + iel);
+	  Printf("%lld,", cor[id]);
+	Printf("%lld", cor[id] + iel);
 	break;
       case LANG_F:
 	/* Fortran variable indices */
-	Printf("%lu", (unsigned long) cor[vrank-1] + iel + 1);
+	Printf("%lld", cor[vrank-1] + iel + 1);
 	for (id = vrank-2; id >=0 ; id--) {
-	    Printf(",%lu", 1 + (unsigned long) cor[id]);
+	    Printf(",%lld", 1 + cor[id]);
 	}
 	break;
     }
@@ -523,9 +523,9 @@ vardata(
      const struct fspec* fsp	/* formatting specs */
      )
 {
-    MPI_Offset cor[NC_MAX_DIMS];	/* corner coordinates */
-    MPI_Offset edg[NC_MAX_DIMS];	/* edges of hypercube */
-    size_t add[NC_MAX_DIMS];	/* "odometer" increment to next "row"  */
+    MPI_Offset *cor;	/* corner coordinates */
+    MPI_Offset *edg;	/* edges of hypercube */
+    size_t *add;	/* "odometer" increment to next "row"  */
  
     int id;
     int ir;
@@ -574,6 +574,10 @@ vardata(
 	initeps = 1;
     }
 
+    cor = (MPI_Offset*) malloc(vrank * sizeof (MPI_Offset));
+    edg = (MPI_Offset*) malloc(vrank * sizeof (MPI_Offset));
+    add = (size_t*) malloc(vrank * sizeof (size_t));
+
     nels = 1;
     for (id = 0; id < vrank; id++) {
 	cor[id] = 0;
@@ -733,6 +737,9 @@ vardata(
         if (vals) memset(vals, 0, VALBUFSIZ);
     }
     free(vals);
+    free(cor);
+    free(edg);
+    free(add);
 
     return 0;
 }
