@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Id: load.c 2320 2016-02-24 13:18:32Z wkliao $
+ *   $Id: load.c 3341 2017-08-25 22:29:08Z wkliao $
  *********************************************************************/
 
 #include <stdio.h>
@@ -75,7 +75,7 @@ gen_load_c(
     long long *int64valp = NULL;
     unsigned long long *uint64valp = NULL;
     char stmnt[C_MAX_STMNT];
-    MPI_Offset stmnt_len;
+    size_t stmnt_len;
     char s2[C_MAX_STMNT];
 
     if (!vars[varnum].has_data)
@@ -144,7 +144,7 @@ gen_load_c(
 		break;
 	      default:
 		derror("Unhandled type %d\n", vars[varnum].type);
-		break;
+		return;
 	    }
             for (ival = 0; ival < var_len-1; ival++) {
 		switch (vars[varnum].type) {
@@ -182,7 +182,7 @@ gen_load_c(
 		    break;
 		  default:
 		    derror("Unhandled type %d\n", vars[varnum].type);
-		    break;
+		    return;
 
 		}
 		stmnt_len += strlen(s2);
@@ -374,7 +374,7 @@ static void
 fstrcat(
     char *s,			/* source string of stement being built */
     const char *t,		/* string to be appended to source */
-    MPI_Offset *slenp			/* pointer to length of source string */
+    size_t *slenp		/* pointer to length of source string */
     )
 {
     *slenp += strlen(t);
@@ -410,7 +410,7 @@ f_var_init(
     long long *int64valp;
     unsigned long long *uint64valp;
     char stmnt[FORT_MAX_STMNT];
-    MPI_Offset stmnt_len;
+    size_t stmnt_len;
     char s2[FORT_MAX_STMNT];
     int ival;
     
@@ -605,8 +605,7 @@ load_netcdf(void *rec_start)
 {
     int i, idim;
     int stat = NC_NOERR;
-    MPI_Offset start[NC_MAX_VAR_DIMS];
-    MPI_Offset count[NC_MAX_VAR_DIMS];
+    MPI_Offset *start, *count;
     char *charvalp = NULL;
     short *shortvalp = NULL;
     int *intvalp = NULL;
@@ -657,6 +656,10 @@ load_netcdf(void *rec_start)
 	derror("Unhandled type %d\n", vars[varnum].type);
 	break;
     }
+
+    start = (MPI_Offset*) malloc(vars[varnum].ndims * 2 * sizeof(MPI_Offset));
+    count = start + vars[varnum].ndims;
+
     if (vars[varnum].ndims > 0) {
 	/* initialize start to upper left corner (0,0,0,...) */
 	start[0] = 0;
@@ -833,4 +836,5 @@ load_netcdf(void *rec_start)
                 break;
         }
     }
+    free(start);
 }
