@@ -4,8 +4,8 @@
  *   $Header$
  *********************************************************************/
 
-#if HAVE_CONFIG_H
-# include <ncconfig.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
 #endif
 
 #include <stdio.h>		/* has getopt() under VMS */
