@@ -2,7 +2,7 @@
  *  Copyright (C) 2015, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: ncoffsets.c 2709 2016-12-16 17:15:57Z wkliao $ */
+/* $Id: ncoffsets.c 3550 2017-11-22 03:52:30Z wkliao $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -50,7 +50,7 @@ static int verbose_debug;
 #define	NC_EINVAL	(-36)	/**< Invalid Argument */
 #define NC_EBADDIM	(-46)	/**< Invalid dimension id or name */
 #define NC_EUNLIMPOS	(-47)	/**< NC_UNLIMITED in the wrong index */
-#define NC_ENOTNC	(-51)	/**< Not a netcdf file */
+#define NC_ENOTNC	(-51)	/**< Not a netcdf file (file format violates CDF specification) */
 #define NC_EVARSIZE     (-62)   /**< One or more variable sizes violate format constraints */
 
 #define NC_UNLIMITED 0L
@@ -228,7 +228,7 @@ swap4b(void *val)
 }
 
 static void
-swap8b(long long *val)
+swap8b(unsigned long long *val)
 {
     uint64_t *op = (uint64_t*)val;
     *op = SWAP8B(*op);
@@ -240,7 +240,7 @@ get_uint64(bufferinfo *gbp) {
     unsigned long long tmp;
     memcpy(&tmp, gbp->pos, 8);
     if (is_little_endian) swap8b(&tmp);
-    gbp->pos += 8;
+    gbp->pos = (char*)gbp->pos + 8;
     return tmp;
 }
 
@@ -250,7 +250,7 @@ get_uint32(bufferinfo *gbp) {
     unsigned int tmp;
     memcpy(&tmp, gbp->pos, 4);
     if (is_little_endian) swap4b(&tmp);
-    gbp->pos += 4;
+    gbp->pos = (char*)gbp->pos + 4;
     return tmp;
 }
 
@@ -781,7 +781,7 @@ hdr_fetch(bufferinfo *gbp) {
 
     assert(gbp->base != NULL);
 
-    slack = gbp->size - (gbp->pos - gbp->base);
+    slack = gbp->size - ((char*)gbp->pos - (char*)gbp->base);
     /* if gbp->pos and gbp->base are the same, there is no leftover buffer
      * data to worry about.
      * In the other extreme, where gbp->size == (gbp->pos - gbp->base), then
@@ -809,7 +809,7 @@ static int
 hdr_check_buffer(bufferinfo *gbp,
                  size_t      nextread)
 {
-    if (gbp->pos + nextread <= gbp->base + gbp->size)
+    if ((char*)gbp->pos + nextread <= (char*)gbp->base + gbp->size)
         return NC_NOERR;
 
     /* read the next chunk from file */
@@ -856,7 +856,7 @@ hdr_get_nc_type(bufferinfo *gbp,
         type != NC_INT64   &&
         type != NC_UINT64
        )
-        DEBUG_RETURN_ERROR(NC_EINVAL);
+        DEBUG_RETURN_ERROR(NC_ENOTNC);
 
     *typep = (nc_type) type;
     return NC_NOERR;
@@ -894,7 +894,7 @@ hdr_get_NC_name(bufferinfo  *gbp,
 
     nbytes = nchars;
     padding = _RNDUP(ncstrp->nchars, X_ALIGN) - ncstrp->nchars;
-    bufremain = gbp->size - (gbp->pos - gbp->base);
+    bufremain = gbp->size - ((char*)gbp->pos - (char*)gbp->base);
     cpos = ncstrp->cp;
 
     /* get namestring with padding */
@@ -918,11 +918,35 @@ hdr_get_NC_name(bufferinfo  *gbp,
 
     /* handle the padding */
     if (padding > 0) {
+#ifdef STRICT_FILE_FORMAT_COMPLIANCE
+        /* CDF specification: Header padding uses null (\x00) bytes.
+         * However, prior to version 4.5.0, NetCDF did not implement this
+         * specification entirely. In particular, it has never enforced the
+         * null-byte padding for attribute values (it has for others, such as
+         * names of dimension, variables, and attributes.) It also appears that
+         * files created by SciPy NetCDF module or NetCDF Java module, both
+         * developed independent from NetCDF-C, also fail to respect this
+         * padding specification.  This becomes a problem for PnetCDF to read
+         * such netCDF files, because PnetCDF enforces the header padding from
+         * its very first release.  The files violating the padding
+         * specification will not be readable by PnetCDF of all releases prior
+         * to 1.9.0 and error code NC_EINVAL or NC_ENOTNC will be thrown when
+         * opening such files.  Note if the sizes of all attribute values of
+         * your files are aligned with 4-byte boundaries, then the files are
+         * readable by PnetCDF.  In order to keep the files in question
+         * readable by PnetCDF, checking for null-byte padding has been
+         * disabled in 1.9.0. But, we keep this checking in ncvalidator, a
+         * utility program that can report whether a CDF file violates the file
+         * format specification, including this null-byte padding. See r3516
+         * and discussion in NetCDF Github issue
+         * https://github.com/Unidata/netcdf-c/issues/657.
+         */
         memset(pad, 0, X_ALIGN-1);
         if (memcmp(gbp->pos, pad, padding) != 0) {
             free(ncstrp);
-            DEBUG_RETURN_ERROR(NC_EINVAL);
+            DEBUG_RETURN_ERROR(NC_ENOTNC);
         }
+#endif
         gbp->pos = (void *)((char *)gbp->pos + padding);
     }
 
@@ -1037,10 +1061,10 @@ hdr_get_NC_dimarray(bufferinfo  *gbp,
     ncap->ndefined = (int)ndefined;
 
     if (ndefined == 0) {
-        if (type != NC_DIMENSION && type != NC_UNSPECIFIED)
-            DEBUG_RETURN_ERROR(NC_EINVAL);
+        if (type != NC_UNSPECIFIED)
+            DEBUG_RETURN_ERROR(NC_ENOTNC);
     } else {
-        if (type != NC_DIMENSION) DEBUG_RETURN_ERROR(NC_EINVAL);
+        if (type != NC_DIMENSION) DEBUG_RETURN_ERROR(NC_ENOTNC);
 
         ncap->value = (NC_dim **) malloc(ndefined * sizeof(NC_dim*));
         MALLOC_CHECK(ncap->value)
@@ -1084,7 +1108,7 @@ hdr_get_NC_attrV(bufferinfo *gbp,
 
     nbytes = attrp->nelems * ncmpix_len_nctype(attrp->type);
     padding = attrp->xsz - nbytes;
-    bufremain = gbp->size - (gbp->pos - gbp->base);
+    bufremain = gbp->size - ((char*)gbp->pos - (char*)gbp->base);
 
     /* get values */
     while (nbytes > 0) {
@@ -1104,9 +1128,33 @@ hdr_get_NC_attrV(bufferinfo *gbp,
 
     /* handle the padding */
     if (padding > 0) {
+#ifdef STRICT_FILE_FORMAT_COMPLIANCE
+        /* CDF specification: Header padding uses null (\x00) bytes.
+         * However, prior to version 4.5.0, NetCDF did not implement this
+         * specification entirely. In particular, it has never enforced the
+         * null-byte padding for attribute values (it has for others, such as
+         * names of dimension, variables, and attributes.) It also appears that
+         * files created by SciPy NetCDF module or NetCDF Java module, both
+         * developed independent from NetCDF-C, also fail to respect this
+         * padding specification.  This becomes a problem for PnetCDF to read
+         * such netCDF files, because PnetCDF enforces the header padding from
+         * its very first release.  The files violating the padding
+         * specification will not be readable by PnetCDF of all releases prior
+         * to 1.9.0 and error code NC_EINVAL or NC_ENOTNC will be thrown when
+         * opening such files.  Note if the sizes of all attribute values of
+         * your files are aligned with 4-byte boundaries, then the files are
+         * readable by PnetCDF.  In order to keep the files in question
+         * readable by PnetCDF, checking for null-byte padding has been
+         * disabled in 1.9.0. But, we keep this checking in ncvalidator, a
+         * utility program that can report whether a CDF file violates the file
+         * format specification, including this null-byte padding. See r3516
+         * and discussion in NetCDF Github issue
+         * https://github.com/Unidata/netcdf-c/issues/657.
+         */
         memset(pad, 0, X_ALIGN-1);
         if (memcmp(gbp->pos, pad, (size_t)padding) != 0)
-            DEBUG_RETURN_ERROR(NC_EINVAL);
+            DEBUG_RETURN_ERROR(NC_ENOTNC);
+#endif
         gbp->pos = (void *)((char *)gbp->pos + padding);
     }
 
@@ -1275,11 +1323,11 @@ hdr_get_NC_attrarray(bufferinfo   *gbp,
     ncap->ndefined = (int)ndefined;
 
     if (ndefined == 0) {
-        if (type != NC_ATTRIBUTE && type != NC_UNSPECIFIED)
-            DEBUG_RETURN_ERROR(NC_EINVAL);
+        if (type != NC_UNSPECIFIED)
+            DEBUG_RETURN_ERROR(NC_ENOTNC);
     } else {
         if (type != NC_ATTRIBUTE)
-            DEBUG_RETURN_ERROR(NC_EINVAL);
+            DEBUG_RETURN_ERROR(NC_ENOTNC);
 
         ncap->value = (NC_attr **)malloc((size_t)ndefined * sizeof(NC_attr*));
         MALLOC_CHECK(ncap->value)
@@ -1487,11 +1535,11 @@ hdr_get_NC_vararray(bufferinfo  *gbp,
     ncap->ndefined = (int)ndefined;
 
     if (ndefined == 0) { /* no variable defined */
-        if (type != NC_VARIABLE && type != NC_UNSPECIFIED)
-            DEBUG_RETURN_ERROR(NC_EINVAL);
+        if (type != NC_UNSPECIFIED)
+            DEBUG_RETURN_ERROR(NC_ENOTNC);
     } else {
         if (type != NC_VARIABLE)
-            DEBUG_RETURN_ERROR(NC_EINVAL);
+            DEBUG_RETURN_ERROR(NC_ENOTNC);
 
         ncap->value = (NC_var **) malloc((size_t)ndefined * sizeof(NC_var*));
         MALLOC_CHECK(ncap->value)
@@ -1548,7 +1596,7 @@ ncmpii_hdr_get_NC(int fd, NC *ncp)
 
     /* First get the file format information, magic */
     magic = getbuf.base;
-    getbuf.pos += 4;
+    getbuf.pos = (char*)getbuf.pos + 4;
 
     /* don't need to worry about CDF-1 or CDF-2
      * if the first bits are not 'CDF'
@@ -1625,6 +1673,7 @@ ncmpii_free_NC(NC *ncp)
     free(ncp->path);
 }
 
+#if 0
 const char *
 ncmpi_strerror(int err)
 {
@@ -1647,6 +1696,7 @@ ncmpi_strerror(int err)
          return "Unknown error code";
    }
 }
+#endif
 
 const char *
 ncmpii_err_code_name(int err)
@@ -1764,7 +1814,7 @@ usage(char *cmd)
 "       [-x]            Check gaps in fixed-size variables, output 1 if gaps\n"
 "                       are found, 0 for otherwise.\n"
 "       file            Input netCDF file name\n"
-"*Parallel netCDF library version 1.7.0\n";
+"*Parallel netCDF library version 1.9.0 of 19 Dec 2017\n";
     fprintf(stderr, help, cmd);
 }
 
@@ -1773,7 +1823,7 @@ int main(int argc, char *argv[])
 {
     extern int optind;
     char *filename, *cmd, *env_str;
-    int i, j, err, opt, nvars;
+    int i, j, err, opt;
     int print_var_size=0, print_gap=0, check_gap=0, print_all_rec=0;
     NC *ncp;
     struct fspec *fspecp=NULL;
@@ -1811,6 +1861,7 @@ int main(int argc, char *argv[])
             free(fspecp->lvars[i]);
         if (fspecp->lvars != NULL) free(fspecp->lvars);
         free(fspecp);
+        free(cmd);
         return 1;
     }
     free(cmd);
