@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: nctst.cpp 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: nctst.cpp 3341 2017-08-25 22:29:08Z wkliao $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -508,7 +508,7 @@ main(int argc, char* argv[])	// test new netCDF interface
    if (argc > 2) {
        if (!rank) printf("Usage: %s [filename]\n",argv[0]);
        MPI_Finalize();
-       return 0;
+       return 1;
    }
    if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
    else           strcpy(filename, "testfile.nc");
@@ -563,7 +563,6 @@ main(int argc, char* argv[])	// test new netCDF interface
         else       printf(PASS_STR);
     }
 
-
-   MPI_Finalize();
-   return nerrs;
+    MPI_Finalize();
+    return (nerrs > 0);
 }
