@@ -2,7 +2,7 @@
  *  Copyright (C) 2013, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: cdf_type.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: cdf_type.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* This program tests if PnetCDF can detect CDF-5 data types that are not
  * available in CDF-1 and CDF-2 formats
@@ -16,8 +16,6 @@
 #include <pnetcdf.h>
 #include <testutils.h>
 
-#define ERR {if(err!=NC_NOERR) {printf("Error(%d) at line %d: %s\n",err,__LINE__,ncmpi_strerror(err)); nerrs++; }}
-
 /*----< test_attr_types() >---------------------------------------------------*/
 static
 int test_attr_types(char *filename,
@@ -32,18 +30,19 @@ int test_attr_types(char *filename,
     cmode = NC_CLOBBER|format;
 
     /* create a file in CDF-1 or CDF-2 format */
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
     for (i=0; i<5; i++) {
         char name[32];
         sprintf(name, "gattr_%d", i);
         err = ncmpi_put_att_int(ncid, NC_GLOBAL, name, xtype[i], 1, &attr);
         if (err != NC_ESTRICTCDF2) {
-            printf("Error (line=%d): expecting NC_ESTRICTCDF2 but got %s\n", __LINE__,nc_err_code_name(err));
+            printf("Error at line %d in %s: expecting NC_ESTRICTCDF2 but got %s\n",
+            __LINE__,__FILE__,ncmpi_strerrno(err));
             nerrs++;
         }
     }
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -63,8 +62,8 @@ int test_var_types(char *filename,
     cmode = NC_CLOBBER|format;
 
     /* create a file in CDF-1 or CDF-2 format */
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim", NC_UNLIMITED, &dimid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim", NC_UNLIMITED, &dimid); CHECK_ERR
     for (i=0; i<5; i++) {
         char name[32];
         sprintf(name, "var_%d", i);
@@ -74,7 +73,7 @@ int test_var_types(char *filename,
             nerrs++;
         }
     }
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -91,7 +90,7 @@ int main(int argc, char **argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -124,6 +123,6 @@ int main(int argc, char **argv)
     }
 
     MPI_Finalize();
-    return (nerrs) ? 2 : 0;
+    return (nerrs > 0);
 }
 
