@@ -2,7 +2,7 @@
  *  Copyright (C) 2013, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: test_inq_format.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: test_inq_format.c 3555 2017-11-22 18:01:35Z wkliao $ */
 
 /* This program tests if PnetCDF can report correct file formats */
 
@@ -14,8 +14,6 @@
 #include <pnetcdf.h>
 #include <testutils.h>
 
-#define ERR {if(err!=NC_NOERR) {printf("Error(%d) at line %d: %s\n",err,__LINE__,ncmpi_strerror(err)); nerrs++; }}
-
 int main(int argc, char **argv) {
     char dir_name[256], filename[256];
     int err, rank, nerrs=0, format, ncid;
@@ -26,7 +24,7 @@ int main(int argc, char **argv) {
     if (argc > 2) {
         if (!rank) printf("Usage: %s dir_name\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(dir_name, 256, "%s", argv[1]);
     else           strcpy(dir_name, ".");
@@ -41,55 +39,70 @@ int main(int argc, char **argv) {
 
     /* test CDF-1 -----------------------------------------------------------*/
     sprintf(filename,"%s/test_cdf1.nc",dir_name);
-    err = ncmpi_open(MPI_COMM_WORLD, filename, 0, MPI_INFO_NULL, &ncid); ERR
-    err = ncmpi_inq_format(ncid, &format); ERR
+    err = ncmpi_open(MPI_COMM_WORLD, filename, 0, MPI_INFO_NULL, &ncid); CHECK_ERR
+
+    /* test NULL argument */
+    err = ncmpi_inq_format(ncid, NULL); CHECK_ERR
+
+    err = ncmpi_inq_format(ncid, &format); CHECK_ERR
     if (format != NC_FORMAT_CLASSIC) {
-        printf("Error (line=%d): expecting CDF-1 format for file %s but got %d\n",
-               __LINE__,filename,format);
+        printf("Error at line %d in %s: expecting CDF-1 format for file %s but got %d\n",
+               __LINE__,__FILE__,filename,format);
         nerrs++;
     }
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
   
-    err = ncmpi_inq_file_format(filename, &format); ERR
+    /* test NULL argument */
+    err = ncmpi_inq_file_format(filename, NULL); CHECK_ERR
+
+    err = ncmpi_inq_file_format(filename, &format); CHECK_ERR
     if (format != NC_FORMAT_CLASSIC) {
-        printf("Error (line=%d): expecting CDF-1 format for file %s but got %d\n",
-               __LINE__,filename,format);
+        printf("Error at line %d in %s: expecting CDF-1 format for file %s but got %d\n",
+               __LINE__,__FILE__,filename,format);
         nerrs++;
     }
 
     /* test CDF-2 -----------------------------------------------------------*/
     sprintf(filename,"%s/test_cdf2.nc",dir_name);
-    err = ncmpi_open(MPI_COMM_WORLD, filename, 0, MPI_INFO_NULL, &ncid); ERR
-    err = ncmpi_inq_format(ncid, &format); ERR
+    err = ncmpi_open(MPI_COMM_WORLD, filename, 0, MPI_INFO_NULL, &ncid); CHECK_ERR
+
+    /* test NULL argument */
+    err = ncmpi_inq_format(ncid, NULL); CHECK_ERR
+
+    err = ncmpi_inq_format(ncid, &format); CHECK_ERR
     if (format != NC_FORMAT_CDF2) {
-        printf("Error (line=%d): expecting CDF-2 format for file %s but got %d\n",
-               __LINE__,filename,format);
+        printf("Error at line %d in %s: expecting CDF-2 format for file %s but got %d\n",
+               __LINE__,__FILE__,filename,format);
         nerrs++;
     }
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
   
-    err = ncmpi_inq_file_format(filename, &format); ERR
+    err = ncmpi_inq_file_format(filename, &format); CHECK_ERR
     if (format != NC_FORMAT_CDF2) {
-        printf("Error (line=%d): expecting CDF-2 format for file %s but got %d\n",
-               __LINE__,filename,format);
+        printf("Error at line %d in %s: expecting CDF-2 format for file %s but got %d\n",
+               __LINE__,__FILE__,filename,format);
         nerrs++;
     }
 
     /* test CDF-5 -----------------------------------------------------------*/
     sprintf(filename,"%s/test_cdf5.nc",dir_name);
-    err = ncmpi_open(MPI_COMM_WORLD, filename, 0, MPI_INFO_NULL, &ncid); ERR
-    err = ncmpi_inq_format(ncid, &format); ERR
+    err = ncmpi_open(MPI_COMM_WORLD, filename, 0, MPI_INFO_NULL, &ncid); CHECK_ERR
+
+    /* test NULL argument */
+    err = ncmpi_inq_format(ncid, NULL); CHECK_ERR
+
+    err = ncmpi_inq_format(ncid, &format); CHECK_ERR
     if (format != NC_FORMAT_CDF5) {
-        printf("Error (line=%d): expecting CDF-5 format for file %s but got %d\n",
-               __LINE__,filename,format);
+        printf("Error at line %d in %s: expecting CDF-5 format for file %s but got %d\n",
+               __LINE__,__FILE__,filename,format);
         nerrs++;
     }
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
   
-    err = ncmpi_inq_file_format(filename, &format); ERR
+    err = ncmpi_inq_file_format(filename, &format); CHECK_ERR
     if (format != NC_FORMAT_CDF5) {
-        printf("Error (line=%d): expecting CDF-5 format for file %s but got %d\n",
-               __LINE__,filename,format);
+        printf("Error at line %d in %s: expecting CDF-5 format for file %s but got %d\n",
+               __LINE__,__FILE__,filename,format);
         nerrs++;
     }
 
@@ -109,5 +122,5 @@ int main(int argc, char **argv) {
     }
 
     MPI_Finalize();
-    return (nerrs) ? 2 : 0;
+    return (nerrs > 0);
 }
