@@ -2,16 +2,36 @@
  *  Copyright (C) 2003, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: testutils.h 2675 2016-12-04 18:55:24Z wkliao $ */
+/* $Id: testutils.h 3414 2017-09-24 01:39:49Z wkliao $ */
 
 
 #ifndef _UTILS_H
 #define _UTILS_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h> /* output of 'configure' */
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include <limits.h>
 
+#define CHECK_ERR { \
+    if (err != NC_NOERR) { \
+        nerrs++; \
+        printf("Error at line %d in %s: (%s)\n", \
+        __LINE__,__FILE__,ncmpi_strerrno(err)); \
+    } \
+}
+
+#define EXP_ERR(exp) { \
+    if (err != exp) { \
+        nerrs++; \
+        printf("Error at line %d in %s: expecting %s but got %s\n", \
+        __LINE__,__FILE__,ncmpi_strerrno(exp), ncmpi_strerrno(err)); \
+    } \
+}
+
 #ifndef PATH_MAX
 #define PATH_MAX 4096
 #endif
@@ -26,9 +46,11 @@ void parse_write_args(int argc, char **argv, int rank, params *p);
 
 #ifdef PNETCDF_DEBUG
 #define PASS_STR "\x1b[32mpass\x1b[0m\n"
+#define SKIP_STR "\x1b[32mskip\x1b[0m\n"
 #define FAIL_STR "\x1b[31mfail\x1b[0m with %d mismatches\n"
 #else
 #define PASS_STR "pass\n"
+#define SKIP_STR "skip\n"
 #define FAIL_STR "fail with %d mismatches\n"
 #endif
 
@@ -42,7 +64,7 @@ void parse_write_args(int argc, char **argv, int rank, params *p);
 
 extern char* nc_err_code_name(int err);
 
-#ifndef MPI_OFFSET
+#ifndef HAVE_DECL_MPI_OFFSET
 #define MPI_OFFSET MPI_LONG_LONG_INT
 #endif
 
