@@ -2,7 +2,7 @@
  *  Copyright (C) 2013, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: header_consistency.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: header_consistency.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* This program tests if PnetCDF can detect file header inconsistency and
  * overwrite the inconsistent header with root's.
@@ -17,26 +17,31 @@
 #include <pnetcdf.h>
 #include <testutils.h>
 
-#define ERR_EXP(e, exp) {if (e != exp) { printf("Error (line %d): expecting error code %s but got %s\n", __LINE__, nc_err_code_name(exp), nc_err_code_name(e)); nerrs++; }}
-#define ERR_EXP2(e, exp1, exp2) {if (e != exp1 && e != exp2 && e != NC_EFILE) { printf("Error (line %d): expecting error code %s or %s but got %s\n", __LINE__, nc_err_code_name(exp1), nc_err_code_name(exp2), nc_err_code_name(e)); nerrs++; }}
+#define EXP_ERR2(e, exp1, exp2) { \
+    if (e != exp1 && e != exp2 && e != NC_EFILE) { \
+        printf("Error at line %d in %s: expecting error code %s or %s but got %s\n", \
+               __LINE__, __FILE__, ncmpi_strerrno(exp1), ncmpi_strerrno(exp2), ncmpi_strerrno(e)); \
+        nerrs++; \
+    } \
+}
 
-#define CHECK_ERR(expect) { \
+#define EXP_SAFE_ERR(expect) { \
     if (safe_mode) { \
         if (err != NC_EMULTIDEFINE && err != expect) { \
-            printf("Error (line %d): expecting error code NC_EMULTIDEFINE or %s but got %s\n", __LINE__, nc_err_code_name(expect), nc_err_code_name(err)); \
+            printf("Error at line %d in %s: expecting error code NC_EMULTIDEFINE or %s but got %s\n", \
+                   __LINE__, __FILE__, ncmpi_strerrno(expect), ncmpi_strerrno(err)); \
             nerrs++; \
         } \
     } \
     else if (rank > 0) { \
         if (err != expect) { \
-            printf("Error (line %d): expecting error code %s but got %s\n", __LINE__, nc_err_code_name(expect), nc_err_code_name(err)); \
+            printf("Error at line %d in %s: expecting error code %s but got %s\n", \
+                   __LINE__, __FILE__, ncmpi_strerrno(expect), ncmpi_strerrno(err)); \
             nerrs++; \
         } \
     } \
 }
 
-#define ERR {if(err!=NC_NOERR) {printf("Error(%d) at line %d: %s\n",err,__LINE__,ncmpi_strerror(err)); nerrs++; }}
-
 /*----< test_open_mode() >----------------------------------------------------*/
 static
 int test_open_mode(char *filename, int safe_mode)
@@ -52,22 +57,27 @@ int test_open_mode(char *filename, int safe_mode)
     if (rank == 0) cmode = NC_CLOBBER;
     err = ncmpi_create(comm, filename, cmode, info, &ncid);
     if (safe_mode)
-        ERR_EXP(err, NC_EMULTIDEFINE_CMODE)
-    else {
-        if (rank > 0) ERR_EXP(err, NC_EMULTIDEFINE_CMODE)
-        err = ncmpi_close(ncid); ERR
-    }
+        /* all processes got the same error code */
+        EXP_ERR(NC_EMULTIDEFINE_CMODE)
+    else if (rank > 0)
+        /* all processes except root got the same error code */
+        EXP_ERR(NC_EMULTIDEFINE_CMODE)
+    /* In either case, file is created with multi-defined-cmode error or not */
+    err = ncmpi_close(ncid); CHECK_ERR
+
 
     /* Test inconsistent omode -----------------------------------------------*/
     omode = NC_WRITE;
     if (rank == 0) omode = NC_NOWRITE;
     err = ncmpi_open(comm, filename, omode, info, &ncid);
     if (safe_mode)
-        ERR_EXP(err, NC_EMULTIDEFINE_OMODE)
-    else {
-        if (rank > 0) ERR_EXP(err, NC_EMULTIDEFINE_OMODE)
-        err = ncmpi_close(ncid); ERR
-    }
+        /* all processes got the same error code */
+        EXP_ERR(NC_EMULTIDEFINE_OMODE)
+    else if (rank > 0)
+        /* all processes except root got the same error code */
+        EXP_ERR(NC_EMULTIDEFINE_OMODE)
+    /* In either case, file is opened with multi-defined-omode error or not */
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -84,41 +94,41 @@ int test_dim(char *filename, int safe_mode)
     cmode = NC_CLOBBER|NC_64BIT_OFFSET;
 
     /* Test inconsistency on dimension names ---------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
     if (rank == 0)
         err = ncmpi_def_dim(ncid, "y", 100, &dimid1);
     else
         err = ncmpi_def_dim(ncid, "xx", 100, &dimid1);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_DIM_NAME)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_DIM_NAME)
     else
-        ERR
-    err = ncmpi_enddef(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     if (safe_mode) {
         /* no processes should be able to see dim "y" */
         err = ncmpi_inq_dimid(ncid, "y", &dimid2);
-        CHECK_ERR(NC_EBADDIM)
+        EXP_SAFE_ERR(NC_EBADDIM)
 
         /* no process should be able to see dim "x" */
         err = ncmpi_inq_dimid(ncid, "xx", &dimid3);
-        CHECK_ERR(NC_EBADDIM)
+        EXP_SAFE_ERR(NC_EBADDIM)
     }
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistency on dimension size ----------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
     if (rank == 0)
         err = ncmpi_def_dim(ncid, "x", 99, &dimid1);
     else
         err = ncmpi_def_dim(ncid, "x", 100, &dimid1);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_DIM_SIZE)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_DIM_SIZE)
     else
-        ERR
+        CHECK_ERR
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
     return nerrs;
 }
 
@@ -137,50 +147,50 @@ int test_attr(char *filename, int safe_mode)
     cmode = NC_CLOBBER|NC_64BIT_OFFSET;
 
     /* Test inconsistent global attribute name -------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
     int_attr = 1;
     sprintf(gattr, "gattr_name.%d",rank);
     err = ncmpi_put_att_int(ncid, NC_GLOBAL, gattr, NC_INT, 1, &int_attr);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_NAME)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_NAME)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent global attribute type -------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
     if (rank == 0)
         err = ncmpi_put_att_int(ncid, NC_GLOBAL, "gatt", NC_INT, 1, &int_attr);
     else
         err = ncmpi_put_att_float(ncid, NC_GLOBAL, "gatt", NC_FLOAT, 1, &flt_attr);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_TYPE)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_TYPE)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent global attribute length -----------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
     int intv[2]={1,2};
     if (rank == 0)
         err = ncmpi_put_att_int(ncid, NC_GLOBAL, "gatt", NC_INT, 2, intv);
     else
         err = ncmpi_put_att_int(ncid, NC_GLOBAL, "gatt", NC_INT, 1, intv);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_LEN)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_LEN)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent global attribute length -----------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
     if (rank == 0) intv[1]=3;
     err = ncmpi_put_att_int(ncid, NC_GLOBAL, "gatt", NC_INT, 2, intv);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_VAL)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_VAL)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -200,127 +210,127 @@ int test_var(char *filename, int safe_mode)
     cmode = NC_CLOBBER|NC_64BIT_OFFSET;
 
     /* Test inconsistent global attribute name -------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); ERR
-    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); CHECK_ERR
     int_attr = 1;
     sprintf(var_attr, "var_attr_name.%d",rank);
     err = ncmpi_put_att_int(ncid, varid1, var_attr, NC_INT, 1, &int_attr);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_NAME)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_NAME)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent global attribute type -------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); ERR
-    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); CHECK_ERR
     if (rank == 0)
         err = ncmpi_put_att_int(ncid, varid1, "var_att", NC_INT, 1, &int_attr);
     else
         err = ncmpi_put_att_float(ncid, varid1, "var_att", NC_FLOAT, 1, &flt_attr);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_TYPE)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_TYPE)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent global attribute length -----------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); ERR
-    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); CHECK_ERR
     int intv[2]={1,2};
     if (rank == 0)
         err = ncmpi_put_att_int(ncid, varid1, "var_att", NC_INT, 2, intv);
     else
         err = ncmpi_put_att_int(ncid, varid1, "var_att", NC_INT, 1, intv);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_LEN)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_LEN)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent global attribute length -----------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); ERR
-    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var1", NC_INT, 1, dimid, &varid1); CHECK_ERR
     if (rank == 0) intv[1]=3;
     err = ncmpi_put_att_int(ncid, varid1, "var_att", NC_INT, 2, intv);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_ATTR_VAL)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_ATTR_VAL)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent variable name ---------------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); CHECK_ERR
     sprintf(name, "var.%d",rank);
     err = ncmpi_def_var(ncid, name, NC_INT, 1, dimid, &varid1);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_VAR_NAME)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_VAR_NAME)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent variable ndims --------------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim0", 3, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "dim1", 2, &dimid[1]); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim0", 3, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", 2, &dimid[1]); CHECK_ERR
     if (rank == 0)
         err = ncmpi_def_var(ncid, "var", NC_FLOAT, 2, dimid, &varid1);
     else
         err = ncmpi_def_var(ncid, "var", NC_FLOAT, 1, dimid, &varid1);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_VAR_NDIMS)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_VAR_NDIMS)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent variable type ---------------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", NC_UNLIMITED, &dimid[0]); CHECK_ERR
     if (rank == 0)
         err = ncmpi_def_var(ncid, "var", NC_INT, 1, dimid, &varid1);
     else
         err = ncmpi_def_var(ncid, "var", NC_FLOAT, 1, dimid, &varid1);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_VAR_TYPE)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_VAR_TYPE)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent variable length -------------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim0", 5, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "dim1", 4, &dimid[1]); ERR
-    err = ncmpi_def_dim(ncid, "dim2", 3, &dimid[2]); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim0", 5, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim1", 4, &dimid[1]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim2", 3, &dimid[2]); CHECK_ERR
     if (rank == 0)
         err = ncmpi_def_var(ncid, "var", NC_FLOAT, 2, dimid, &varid1);
     else
         err = ncmpi_def_var(ncid, "var", NC_FLOAT, 2, dimid+1, &varid1);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_VAR_DIMIDS)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_VAR_DIMIDS)
     else
-        ERR
-    err = ncmpi_close(ncid); ERR
+        CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* Test inconsistent variable dimension IDs ------------------------------*/
-    err = ncmpi_create(comm, filename, cmode, info, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "Z", 3, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "Y", 3, &dimid[1]); ERR
-    err = ncmpi_def_dim(ncid, "X", 3, &dimid[2]); ERR
+    err = ncmpi_create(comm, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "Z", 3, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "Y", 3, &dimid[1]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "X", 3, &dimid[2]); CHECK_ERR
     if (rank == 0)
         err = ncmpi_def_var(ncid, "var", NC_FLOAT, 2, dimid+1, &varid1);
     else
         err = ncmpi_def_var(ncid, "var", NC_FLOAT, 2, dimid, &varid1);
     if (safe_mode)
-        CHECK_ERR(NC_EMULTIDEFINE_VAR_DIMIDS)
+        EXP_SAFE_ERR(NC_EMULTIDEFINE_VAR_DIMIDS)
     else
-        ERR
+        CHECK_ERR
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -338,13 +348,13 @@ int main(int argc, char **argv)
     if (nprocs < 2) {
         if (!rank) printf("This program is for running 2 or more processes. Exiting ...\n");
         MPI_Finalize();
-        return 0;
+        return 1;
     }
 
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) filename = argv[1];
 
@@ -388,6 +398,6 @@ int main(int argc, char **argv)
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
