@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: large_var.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: large_var.c 3622 2017-12-19 00:55:10Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -32,16 +32,14 @@
 #include <pnetcdf.h>
 #include <testutils.h>
 
-#define FOUR_G 4294967296
-#define TWO_G  2147483648
-#define ONE_G  1073741824
+#define FOUR_G 4294967296LL
+#define TWO_G  2147483648LL
+#define ONE_G  1073741824LL
 
 #define NZ 4
 #define NY 10
 #define NX FOUR_G
 
-#define ERR if (err!=NC_NOERR) {printf("Error at line %d: err=%s (%s)\n", __LINE__,nc_err_code_name(err),ncmpi_strerror(err)); exit(-1);}
-
 #ifndef WORDS_BIGENDIAN
 /* Endianness byte swap: done in-place */
 #define SWAP(x,y) {tmp = (x); (x) = (y); (y) = tmp;}
@@ -77,7 +75,7 @@ int main(int argc, char** argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -93,113 +91,160 @@ int main(int argc, char** argv)
     /* create a new file for writing ----------------------------------------*/
     cmode = NC_CLOBBER | NC_64BIT_DATA;
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    ERR
+    CHECK_ERR
 
     /* define dimensions Z, Y, and X */
     err = ncmpi_def_dim(ncid, "Z", NZ, &dimid[0]);
-    ERR
+    CHECK_ERR
     err = ncmpi_def_dim(ncid, "Y", NY, &dimid[1]);
-    ERR
+    CHECK_ERR
     err = ncmpi_def_dim(ncid, "X", NX, &dimid[2]);
-    ERR
+    CHECK_ERR
 
-    /* define a 3D variable of integer type */
+    /* define a big 1D variable of ubyte type, so there are 2 big variables */
+    err = ncmpi_def_var(ncid, "big_1D", NC_UBYTE, 1, &dimid[2], &varid);
+    CHECK_ERR
+
+    /* define a big 3D variable of integer type */
     err = ncmpi_def_var(ncid, "var", NC_INT, 3, dimid, &varid);
-    ERR
+    CHECK_ERR
 
     /* do not forget to exit define mode */
     err = ncmpi_enddef(ncid);
-    ERR
+    CHECK_ERR
 
-    /* get the beginning of file offset for the varaiable */
+    /* get the beginning of file offset for the variable */
     err = ncmpi_inq_varoffset(ncid, varid, &var_offset);
-    ERR
+    CHECK_ERR
 
     /* now we are in data mode */
     start[0] = 1;
-    start[1] = NY - 2;
+    start[1] = 8;
     start[2] = TWO_G + 10 * rank;
     count[0] = 1;
     count[1] = 2;
     count[2] = 10;
 
-    bufsize = count[0]*count[1]*count[2];
-    buf = (int*) malloc(bufsize * sizeof(int));
-    for (i=0; i<bufsize; i++) buf[i] = rank*100 + i;
+    buf = (int*) malloc(40 * sizeof(int));
+    for (i=0; i<40; i++) buf[i] = rank*100 + i;
 
     err = ncmpi_put_vara_int_all(ncid, varid, start, count, buf);
-    ERR
+    CHECK_ERR
 
     /* now test nonblocking put */
-    /* rearrange buffer contents */
-    for (i=5;  i<10; i++) buf[i] = rank*100 + i + 5;
-    for (i=10; i<15; i++) buf[i] = rank*100 + i - 5;
-
-    start[0] = NZ-1;
+    start[0] = 3;
     count[2] = 5;
-    err = ncmpi_iput_vara_int(ncid, varid, start, count, buf, &req[0]);
-    ERR
+    err = ncmpi_iput_vara_int(ncid, varid, start, count, buf+20, &req[0]);
+    CHECK_ERR
 
     start[2] += 5;
     count[1]  = 1;
-    err = ncmpi_iput_vara_int(ncid, varid, start, count, buf+10, &req[1]);
-    ERR
+    err = ncmpi_iput_vara_int(ncid, varid, start, count, buf+30, &req[1]);
+    CHECK_ERR
 
-    start[1]++;
-    err = ncmpi_iput_vara_int(ncid, varid, start, count, buf+15, &req[2]);
-    ERR
+    start[1] = 9;
+    err = ncmpi_iput_vara_int(ncid, varid, start, count, buf+35, &req[2]);
+    CHECK_ERR
 
     err = ncmpi_wait_all(ncid, 3, req, st);
-    ERR
+    CHECK_ERR
+    for (i=0; i<3; i++) {
+        err = st[i];
+        CHECK_ERR
+    }
 
     err = ncmpi_close(ncid);
-    ERR
+    CHECK_ERR
 
     /* open the same file and read back for validation */
     err = ncmpi_open(MPI_COMM_WORLD, filename, NC_NOWRITE, MPI_INFO_NULL,
-                     &ncid); ERR
+                     &ncid); CHECK_ERR
 
-    err = ncmpi_inq_varid(ncid, "var", &varid); ERR
-
-    /* initialize the contents of the array to a different value */
-    for (i=0; i<bufsize; i++) buf[i] = -1;
+    err = ncmpi_inq_varid(ncid, "var", &varid); CHECK_ERR
 
     /* read back subarray written by the process (rank+1)%nprocs */
     start[0] = 1;
-    start[1] = NY - 2;
+    start[1] = 8;
     start[2] = TWO_G + ((rank == nprocs - 1) ? 0 : 10 * (rank + 1));
     count[0] = 1;
     count[1] = 2;
     count[2] = 10;
 
-    err = ncmpi_get_vara_int_all(ncid, varid, start, count, buf); ERR
-
-    /* check if the contents of buf are expected */
-    for (i=0; i<bufsize; i++) {
-        int expected = (rank == nprocs - 1) ? i : (rank+1)*100 + i;
-        if (buf[i] != expected) {
-            printf("%d (at line %d): Unexpected read buf[%d]=%d, should be %d\n",
-                   rank, __LINE__, i, buf[i], expected);
-            nerrs++;
-        }
-    }
-
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
     for (i=0; i<bufsize; i++) buf[i] = -1;
 
-    start[0] = NZ-1;
-    err = ncmpi_get_vara_int_all(ncid, varid, start, count, buf); ERR
+    err = ncmpi_get_vara_int_all(ncid, varid, start, count, buf); CHECK_ERR
+
+    int expected = (rank == nprocs - 1) ? 0 : (rank+1)*100;
 
     /* check if the contents of buf are expected */
     for (i=0; i<bufsize; i++) {
-        int expected = (rank == nprocs - 1) ? i : (rank+1)*100 + i;
         if (buf[i] != expected) {
-            printf("%d (at line %d): Unexpected read buf[%d]=%d, should be %d\n",
-                   rank, __LINE__, i, buf[i], expected);
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
             nerrs++;
         }
+        expected++;
     }
 
-    err = ncmpi_close(ncid); ERR
+    start[0] = 3;
+    count[2] = 5;
+
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
+    for (i=0; i<bufsize; i++) buf[i] = -1;
+
+    err = ncmpi_get_vara_int_all(ncid, varid, start, count, buf); CHECK_ERR
+
+    /* check if the contents of buf are expected */
+    for (i=0; i<bufsize; i++) {
+        if (buf[i] != expected) {
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
+            nerrs++;
+        }
+        expected++;
+    }
+
+    start[2] += 5;
+    count[1] = 1;
+
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
+    for (i=0; i<bufsize; i++) buf[i] = -1;
+
+    err = ncmpi_get_vara_int_all(ncid, varid, start, count, buf); CHECK_ERR
+
+    /* check if the contents of buf are expected */
+    for (i=0; i<bufsize; i++) {
+        if (buf[i] != expected) {
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
+            nerrs++;
+        }
+        expected++;
+    }
+
+    start[1] = 9;
+
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
+    for (i=0; i<bufsize; i++) buf[i] = -1;
+
+    err = ncmpi_get_vara_int_all(ncid, varid, start, count, buf); CHECK_ERR
+
+    /* check if the contents of buf are expected */
+    for (i=0; i<bufsize; i++) {
+        if (buf[i] != expected) {
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
+            nerrs++;
+        }
+        expected++;
+    }
+
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* MPI file open the same file and read back for validation */
     err = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_RDONLY, MPI_INFO_NULL, &fh);
@@ -210,42 +255,47 @@ int main(int argc, char** argv)
         printf("MPI error MPI_File_open : %s\n", errorString);
     }
 
-    /* initialize the contents of the array to a different value */
-    for (i=0; i<bufsize; i++) buf[i] = -1;
-
     /* read back subarray written by the process (rank+1)%nprocs */
     start[0] = 1;
-    start[1] = NY - 2;
+    start[1] = 8;
     start[2] = TWO_G + ((rank == nprocs - 1) ? 0 : 10 * (rank + 1));
     count[0] = 1;
     count[1] = 2;
     count[2] = 10;
 
-    buf_ptr = buf;
-    for (i=0; i<count[0]; i++) {
-        for (j=0; j<count[1]; j++) {
-            offset = var_offset + ((start[0] + i) * NY * NX + (start[1] + j) * NX + start[2]) * sizeof(int);
-            MPI_File_read_at(fh, offset, buf_ptr, count[2], MPI_INT, &status);
-#ifndef WORDS_BIGENDIAN
-            swapn(buf_ptr, count[2]);
-#endif
-            buf_ptr += count[2];
-        }
-    }
-
-    /* check if the contents of buf are expected */
-    for (i=0; i<bufsize; i++) {
-        int expected = (rank == nprocs - 1) ? i : (rank+1)*100 + i;
-        if (buf[i] != expected) {
-            printf("%d (at line %d): Unexpected read buf[%d]=%d, should be %d\n",
-                   rank, __LINE__, i, buf[i], expected);
-            nerrs++;
-        }
-    }
-
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
     for (i=0; i<bufsize; i++) buf[i] = -1;
 
-    start[0] = NZ-1;
+    buf_ptr = buf;
+    for (i=0; i<count[0]; i++) {
+        for (j=0; j<count[1]; j++) {
+            offset = var_offset + ((start[0] + i) * NY * NX + (start[1] + j) * NX + start[2]) * sizeof(int);
+            MPI_File_read_at(fh, offset, buf_ptr, count[2], MPI_INT, &status);
+#ifndef WORDS_BIGENDIAN
+            swapn(buf_ptr, count[2]);
+#endif
+            buf_ptr += count[2];
+        }
+    }
+
+    expected = (rank == nprocs - 1) ? 0 : (rank+1)*100;
+    /* check if the contents of buf are expected */
+    for (i=0; i<bufsize; i++) {
+        if (buf[i] != expected) {
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
+            nerrs++;
+        }
+        expected++;
+    }
+
+    start[0] = 3;
+    count[2] = 5;
+
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
+    for (i=0; i<bufsize; i++) buf[i] = -1;
 
     buf_ptr = buf;
     for (i=0; i<count[0]; i++) {
@@ -261,12 +311,69 @@ int main(int argc, char** argv)
 
     /* check if the contents of buf are expected */
     for (i=0; i<bufsize; i++) {
-        int expected = (rank == nprocs - 1) ? i : (rank+1)*100 + i;
         if (buf[i] != expected) {
-            printf("%d (at line %d): Unexpected read buf[%d]=%d, should be %d\n",
-                   rank, __LINE__, i, buf[i], expected);
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
             nerrs++;
         }
+        expected++;
+    }
+
+    start[2] += 5;
+    count[1]  = 1;
+
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
+    for (i=0; i<bufsize; i++) buf[i] = -1;
+
+    buf_ptr = buf;
+    for (i=0; i<count[0]; i++) {
+        for (j=0; j<count[1]; j++) {
+            offset = var_offset + ((start[0] + i) * NY * NX + (start[1] + j) * NX + start[2]) * sizeof(int);
+            MPI_File_read_at(fh, offset, buf_ptr, count[2], MPI_INT, &status);
+#ifndef WORDS_BIGENDIAN
+            swapn(buf_ptr, count[2]);
+#endif
+            buf_ptr += count[2];
+        }
+    }
+
+    /* check if the contents of buf are expected */
+    for (i=0; i<bufsize; i++) {
+        if (buf[i] != expected) {
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
+            nerrs++;
+        }
+        expected++;
+    }
+
+    start[1] = 9;
+
+    /* initialize the contents of the array to a different value */
+    bufsize = count[0]*count[1]*count[2];
+    for (i=0; i<bufsize; i++) buf[i] = -1;
+
+    buf_ptr = buf;
+    for (i=0; i<count[0]; i++) {
+        for (j=0; j<count[1]; j++) {
+            offset = var_offset + ((start[0] + i) * NY * NX + (start[1] + j) * NX + start[2]) * sizeof(int);
+            MPI_File_read_at(fh, offset, buf_ptr, count[2], MPI_INT, &status);
+#ifndef WORDS_BIGENDIAN
+            swapn(buf_ptr, count[2]);
+#endif
+            buf_ptr += count[2];
+        }
+    }
+
+    /* check if the contents of buf are expected */
+    for (i=0; i<bufsize; i++) {
+        if (buf[i] != expected) {
+            printf("Error file %s line %d: expect buf[%d]=%d, but got %d\n",
+                   __FILE__, __LINE__, i, expected, buf[i]);
+            nerrs++;
+        }
+        expected++;
     }
 
     MPI_File_close(&fh);
@@ -290,6 +397,6 @@ int main(int argc, char** argv)
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
