@@ -2,7 +2,7 @@
  *  Copyright (C) 2014, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: tst_misc.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: tst_misc.c 3604 2017-12-16 09:21:02Z wkliao $ */
 
 /* This program is based on the test program tst_misc.c of the netCDF package */
 
@@ -28,7 +28,7 @@ int
 main(int argc, char **argv) 
 {
     char *cmd_str, filename[256];
-    int rank, nprocs, err, nerrs=0;
+    int rank, nprocs, err, nerrs=0, ncid;
 
     MPI_Init(&argc, &argv);
     MPI_Comm_size(MPI_COMM_WORLD, &nprocs);
@@ -37,7 +37,7 @@ main(int argc, char **argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (rank > 0) goto fn_exit;
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
@@ -51,12 +51,11 @@ main(int argc, char **argv)
    printf("\n*** Testing some extra stuff.\n");
    printf("*** Trying to open non-netCDF files of tiny length...");
 */
-   {
+    {
 #define DATA_LEN 32    
-     int ncid,openstat;
       char dummy_data[DATA_LEN];
+      int i, openstat;
       FILE *file;
-      int i, nerrs=0;
 
       /* Appease valgrind by initializing our data. */
       for (i = 0; i < DATA_LEN; i++)
@@ -64,8 +63,16 @@ main(int argc, char **argv)
 
       for (i = DATA_LEN; i >= 0; i--)
       {
-	 /* Create a small file which is not a netCDF file. */
-	 if (!(file = fopen(filename, "w+"))) nerrs++;
+	 /* Create a small file which is not a netCDF file.
+          * remove the file system type prefix name if there is any.
+          * For example, when filename = "lustre:/home/foo/testfile.nc", remove
+          * "lustre:" to make path = "/home/foo/testfile.nc" in open() below
+          */
+         char *path = strchr(filename, ':');
+         if (path == NULL) path = filename; /* no prefix */
+         else              path++;
+
+	 if (!(file = fopen(path, "w+"))) nerrs++;
          else {
 	     if (fwrite(dummy_data, 1, i, file) != i) nerrs++;
 	     if (fclose(file)) nerrs++;
@@ -83,6 +90,10 @@ main(int argc, char **argv)
       }
    }
 
+   err = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER, MPI_INFO_NULL,
+                      &ncid); CHECK_ERR
+   err = ncmpi_close(ncid); CHECK_ERR
+
     /* check if PnetCDF freed all internal malloc */
     MPI_Offset malloc_size, sum_size;
     err = ncmpi_inq_malloc_size(&malloc_size);
@@ -101,5 +112,5 @@ fn_exit:
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
