@@ -2,7 +2,7 @@
  *  Copyright (C) 2014, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: tst_names.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: tst_names.c 3440 2017-10-15 18:46:02Z wkliao $ */
 
 /* This program is based on the test program tst_names.c of the netCDF package */
 
@@ -199,9 +199,12 @@ main(int argc, char **argv)
        "x\xED\xAE\x80\xED\xB0\x80",
        "x\xED\xAE\x80\xED\xBF\xBF",
        "x\xED\xAF\xBF\xED\xB0\x80",
-       "x\xED\xAF\xBF\xED\xBF\xBF",
+       "x\xED\xAF\xBF\xED\xBF\xBF"
+#if 0
+       /* The two below is legal since UTF8PROC_VERSION_MAJOR 2 */
        "x\xEF\xBF\xBE",		/* other illegal code positions */
        "x\xEF\xBF\xBF"
+#endif
    };
    int i, j;
 #define NUM_BAD (sizeof notvalid / sizeof notvalid[0])
@@ -230,7 +233,7 @@ main(int argc, char **argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -325,5 +328,5 @@ main(int argc, char **argv)
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
