@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: i_varn_indef.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: i_varn_indef.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * This example tests posting nonblocking varn APIs, including
@@ -70,27 +70,21 @@
 #define NX 10
 #define NDIMS 2
 
-#define ERR \
-    if (err != NC_NOERR) { \
-        printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err)); \
-        nerrs++; \
-    }
-
 #define ERRS(n,a) { \
     int _i; \
     for (_i=0; _i<(n); _i++) { \
         if ((a)[_i] != NC_NOERR) { \
-            printf("Error at line=%d: err[%d] %s\n", __LINE__, _i, \
-                   ncmpi_strerror((a)[_i])); \
+            printf("Error at line %d in %s: err[%d] %s\n", __LINE__, __FILE__, _i, \
+                   ncmpi_strerrno((a)[_i])); \
             nerrs++; \
         } \
     } \
 }
 
 static
-void clear_file_contents(int ncid, int *varid)
+int clear_file_contents(int ncid, int *varid)
 {
-    int i, err, rank;
+    int i, err, nerrs=0, rank;
     long long *w_buffer = (long long*) malloc(NY*NX * sizeof(long long));
     for (i=0; i<NY*NX; i++) w_buffer[i] = -1;
 
@@ -98,16 +92,17 @@ void clear_file_contents(int ncid, int *varid)
 
     for (i=0; i<4; i++) {
         err = ncmpi_put_var_longlong_all(ncid, varid[i], w_buffer);
-        if (err != NC_NOERR) printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));
+        CHECK_ERR
     }
     free(w_buffer);
+    return nerrs;
 }
 
 static
 int check_contents_for_fail(int ncid, int *varid, int lineno)
 {
     /* all processes read entire variables back and check contents */
-    int i, j, err, nprocs;
+    int i, j, err, nerrs=0, nprocs;
     long long expected[4][NY*NX] = {{13, 13, 13, 11, 11, 10, 10, 12, 11, 11,
                                      10, 12, 12, 12, 13, 11, 11, 12, 12, 12,
                                      11, 11, 12, 13, 13, 13, 10, 10, 11, 11,
@@ -133,36 +128,35 @@ int check_contents_for_fail(int ncid, int *varid, int lineno)
     for (i=0; i<4; i++) {
         for (j=0; j<NY*NX; j++) r_buffer[j] = -1;
         err = ncmpi_get_var_longlong_all(ncid, varid[i], r_buffer);
-        if (err != NC_NOERR) printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));
+        CHECK_ERR
 
         /* check if the contents of buf are expected */
         for (j=0; j<NY*NX; j++) {
             if (expected[i][j] >= nprocs) continue;
             if (r_buffer[j] != expected[i][j]) {
-                printf("Error from line %d: Expected read buf[%d][%d]=%lld, but got %lld\n",
-                       lineno,i,j,expected[i][j],r_buffer[j]);
-                free(r_buffer);
-                return 1;
+                printf("Error at line %d in %s: Expected read buf[%d][%d]=%lld, but got %lld\n",
+                       lineno,__FILE__,i,j,expected[i][j],r_buffer[j]);
+                nerrs++;
             }
         }
     }
     free(r_buffer);
-    return 0;
+    return nerrs;
 }
 
 static int
 check_num_pending_reqs(int ncid, int expected, int lineno)
 /* check if PnetCDF can reports expected number of pending requests */
 {
-    int err, n_pendings;
+    int err, nerrs=0, n_pendings;
     err = ncmpi_inq_nreqs(ncid, &n_pendings);
-    if (err != NC_NOERR) printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));
+    CHECK_ERR
     if (n_pendings != expected) {
-        printf("Error at line %d: expect %d pending requests but got %d\n",
-               lineno, expected, n_pendings);
-        return 1;
+        printf("Error at line %d in %s: expect %d pending requests but got %d\n",
+               lineno, __FILE__, expected, n_pendings);
+        nerrs++;
     }
-    return 0;
+    return nerrs;
 }
 
 /* swap two rows, a and b, of a 2D array */
@@ -223,7 +217,7 @@ int main(int argc, char** argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -304,20 +298,20 @@ int main(int argc, char** argv)
     /* create a new file for writing ----------------------------------------*/
     cmode = NC_CLOBBER | NC_64BIT_DATA;
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    ERR
+    CHECK_ERR
 
     /* create a global array of size NY * NX */
-    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); ERR
+    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); CHECK_ERR
 
     /* post write requests while still in define mode */
     for (i=0; i<4; i++) {
         err = ncmpi_def_var(ncid, varname[i], NC_INT64, NDIMS, dimid, &varid[i]);
-        ERR
+        CHECK_ERR
 
         err = ncmpi_iput_varn_longlong(ncid, varid[i], my_nsegs[i], starts[i],
                                        counts[i], buffer[i], &reqs[i]);
-        ERR
+        CHECK_ERR
     }
 
     /* test error code: NC_ENULLSTART */
@@ -329,20 +323,22 @@ int main(int argc, char** argv)
         nerrs++;
     }
 
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     /* clear the file contents using a blocking API, before commit the
      * nonblocking requests posted in define mode */
-    clear_file_contents(ncid, varid);
+    nerrs += clear_file_contents(ncid, varid);
     nerrs += check_num_pending_reqs(ncid, nreqs, __LINE__);
     err = ncmpi_wait_all(ncid, nreqs, reqs, sts);
+    CHECK_ERR
     ERRS(nreqs, sts)
 
     /* check if write buffer contents have been altered */
     for (i=0; i<nreqs; i++) {
         for (j=0; j<req_lens[i]; j++) {
             if (buffer[i][j] != rank+10) {
-                printf("Error: put buffer altered buffer[%d][%d]=%lld\n", i,j,buffer[i][j]);
+                printf("Error at line %d in %s: put buffer altered buffer[%d][%d]=%lld\n",
+                       __LINE__,__FILE__,i,j,buffer[i][j]);
                 nerrs++;
             }
         }
@@ -351,7 +347,7 @@ int main(int argc, char** argv)
     /* all processes read entire variables back and check contents */
     nerrs += check_contents_for_fail(ncid, varid, __LINE__);
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* try with buffer being a single contiguous space ----------------------*/
     for (i=0; i<nreqs; i++) bufsize += req_lens[i];
@@ -363,35 +359,37 @@ int main(int argc, char** argv)
     /* create a new file for writing */
     cmode = NC_CLOBBER | NC_64BIT_DATA;
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    ERR
+    CHECK_ERR
 
     /* create a global array of size NY * NX */
-    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); ERR
+    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); CHECK_ERR
 
     /* post write requests while still in define mode */
     for (i=0; i<4; i++) {
         err = ncmpi_def_var(ncid, varname[i], NC_INT64, NDIMS, dimid, &varid[i]);
-        ERR
+        CHECK_ERR
 
         err = ncmpi_iput_varn_longlong(ncid, varid[i], my_nsegs[i], starts[i],
                                        counts[i], cbuffer[i], &reqs[i]);
-        ERR
+        CHECK_ERR
     }
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     /* clear the file contents using a blocking API, before commit the
      * nonblocking requests posted in define mode */
-    clear_file_contents(ncid, varid);
+    nerrs += clear_file_contents(ncid, varid);
     nerrs += check_num_pending_reqs(ncid, nreqs, __LINE__);
     err = ncmpi_wait_all(ncid, nreqs, reqs, sts);
+    CHECK_ERR
     ERRS(nreqs, sts)
 
     /* check if write buffer contents have been altered */
     for (i=0; i<nreqs; i++) {
         for (j=0; j<req_lens[i]; j++) {
             if (cbuffer[i][j] != rank+10) {
-                printf("Error: put buffer altered buffer[%d][%d]=%lld\n", i,j,cbuffer[i][j]);
+                printf("Error at line %d in %s: put buffer altered buffer[%d][%d]=%lld\n",
+                       __LINE__,__FILE__,i,j,cbuffer[i][j]);
                 nerrs++;
             }
         }
@@ -400,7 +398,7 @@ int main(int argc, char** argv)
     /* all processes read entire variables back and check contents */
     nerrs += check_contents_for_fail(ncid, varid, __LINE__);
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* permute write order: so starts[*] are not in an increasing order:
      * swap segment 0 with segment 2 and swap segment 1 with segment 3
@@ -413,20 +411,20 @@ int main(int argc, char** argv)
     /* create a new file for writing */
     cmode = NC_CLOBBER | NC_64BIT_DATA;
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    ERR
+    CHECK_ERR
 
     /* create a global array of size NY * NX */
-    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); ERR
+    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); CHECK_ERR
 
     /* write requests request while still in define mode */
     for (i=0; i<4; i++) {
         err = ncmpi_def_var(ncid, varname[i], NC_INT64, NDIMS, dimid, &varid[i]);
-        ERR
+        CHECK_ERR
 
         err = ncmpi_iput_varn_longlong(ncid, varid[i], my_nsegs[i], starts[i],
                                        counts[i], buffer[i], &reqs[i]);
-        ERR
+        CHECK_ERR
     }
 
     /* post read requests while still in define mode */
@@ -434,23 +432,25 @@ int main(int argc, char** argv)
         for (j=0; j<req_lens[i]; j++) cbuffer[i][j] = -1;
         err = ncmpi_iget_varn_longlong(ncid, varid[i], my_nsegs[i], starts[i],
                                        counts[i], cbuffer[i], &reqs[4+i]);
-        ERR
+        CHECK_ERR
     }
 
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     /* clear the file contents using a blocking API, before commit the
      * nonblocking requests posted in define mode */
-    clear_file_contents(ncid, varid);
+    nerrs += clear_file_contents(ncid, varid);
     nerrs += check_num_pending_reqs(ncid, nreqs*2, __LINE__);
     err = ncmpi_wait_all(ncid, nreqs, reqs, sts);
+    CHECK_ERR
     ERRS(nreqs, sts)
 
     /* check if write buffer contents have been altered */
     for (i=0; i<nreqs; i++) {
         for (j=0; j<req_lens[i]; j++) {
             if (buffer[i][j] != rank+10) {
-                printf("Error: put buffer altered buffer[%d][%d]=%lld\n", i,j,buffer[i][j]);
+                printf("Error at line %d in %s: put buffer altered buffer[%d][%d]=%lld\n",
+                       __LINE__,__FILE__,i,j,buffer[i][j]);
                 nerrs++;
             }
         }
@@ -461,15 +461,16 @@ int main(int argc, char** argv)
     /* commit read requests */
     nerrs += check_num_pending_reqs(ncid, nreqs, __LINE__);
     err = ncmpi_wait_all(ncid, nreqs, reqs+4, sts);
+    CHECK_ERR
     ERRS(nreqs, sts)
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     for (i=0; i<nreqs; i++) {
         for (j=0; j<req_lens[i]; j++) {
             if (cbuffer[i][j] != rank+10) {
-                printf("Error at line %d: expecting cbuffer[%d][%d]=%d but got %lld\n",
-                       __LINE__,i,j,rank+10,cbuffer[i][j]);
+                printf("Error at line %d in %s: expecting cbuffer[%d][%d]=%d but got %lld\n",
+                       __LINE__,__FILE__,i,j,rank+10,cbuffer[i][j]);
                 nerrs++;
             }
         }
@@ -490,26 +491,26 @@ int main(int argc, char** argv)
     /* create a new file for writing */
     cmode = NC_CLOBBER | NC_64BIT_DATA;
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    ERR
+    CHECK_ERR
 
     /* create a global array of size NY * NX */
-    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); ERR
+    err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]); CHECK_ERR
 
     /* write requests request while still in define mode */
     for (i=0; i<4; i++) {
         err = ncmpi_def_var(ncid, varname[i], NC_INT64, NDIMS, dimid, &varid[i]);
-        ERR
+        CHECK_ERR
 
         err = ncmpi_iput_varn(ncid, varid[i], my_nsegs[i], starts[i], counts[i],
-                              buffer[i], 1, buftype[i], &reqs[i]); ERR
-        ERR
+                              buffer[i], 1, buftype[i], &reqs[i]);
+        CHECK_ERR
     }
     /* test flexible get API, using a noncontiguous buftype */
     for (i=0; i<nreqs; i++) {
         err = ncmpi_iget_varn(ncid, varid[i], my_nsegs[i], starts[i], counts[i],
                               rbuffer[i], 1, buftype[i], &reqs[i+4]);
-        ERR
+        CHECK_ERR
     }
 
     for (i=0; i<nreqs; i++) MPI_Type_free(&buftype[i]);
@@ -526,16 +527,17 @@ int main(int argc, char** argv)
     for (i=0; i<nreqs; i++) {
         err = ncmpi_iget_varn_longlong(ncid, varid[i], my_nsegs[i], starts[i],
                                        counts[i], cbuffer[i], &reqs[i+8]);
-        ERR
+        CHECK_ERR
     }
 
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     /* clear the file contents using a blocking API, before commit the
      * nonblocking requests posted in define mode */
-    clear_file_contents(ncid, varid);
+    nerrs += clear_file_contents(ncid, varid);
     nerrs += check_num_pending_reqs(ncid, nreqs*3, __LINE__);
     err = ncmpi_wait_all(ncid, nreqs, reqs, sts);
+    CHECK_ERR
     ERRS(nreqs, sts)
 
     /* all processes read entire variables back and check contents */
@@ -544,18 +546,19 @@ int main(int argc, char** argv)
     /* flush nonblocking 1st batch read requests */
     nerrs += check_num_pending_reqs(ncid, nreqs*2, __LINE__);
     err = ncmpi_wait_all(ncid, nreqs, reqs+4, sts);
+    CHECK_ERR
     ERRS(nreqs, sts)
 
     for (i=0; i<nreqs; i++) {
         for (j=0; j<req_lens[i]*2; j++) {
             if (j%2 && rbuffer[i][j] != -1) {
-                printf("Error at line %d: expecting rbuffer[%d][%d]=-1 but got %lld\n",
-                       __LINE__,i,j,rbuffer[i][j]);
+                printf("Error at line %d in %s: expecting rbuffer[%d][%d]=-1 but got %lld\n",
+                       __LINE__,__FILE__,i,j,rbuffer[i][j]);
                 nerrs++;
             }
             if (j%2 == 0 && rbuffer[i][j] != rank+10) {
-                printf("Error at line %d: expecting rbuffer[%d][%d]=%d but got %lld\n",
-                       __LINE__,i,j,rank+10,rbuffer[i][j]);
+                printf("Error at line %d in %s: expecting rbuffer[%d][%d]=%d but got %lld\n",
+                       __LINE__,__FILE__,i,j,rank+10,rbuffer[i][j]);
                 nerrs++;
             }
         }
@@ -564,20 +567,21 @@ int main(int argc, char** argv)
     /* flush nonblocking 2nd batch read requests */
     nerrs += check_num_pending_reqs(ncid, nreqs, __LINE__);
     err = ncmpi_wait_all(ncid, nreqs, reqs+8, sts);
+    CHECK_ERR
     ERRS(nreqs, sts)
 
     for (i=0; i<nreqs; i++) {
         for (j=0; j<req_lens[i]; j++) {
             if (cbuffer[i][j] != rank+10) {
-                printf("Error at line %d: expecting buffer[%d][%d]=%d but got %lld\n",
-                       __LINE__,i,j,rank+10,cbuffer[i][j]);
+                printf("Error at line %d in %s: expecting buffer[%d][%d]=%d but got %lld\n",
+                       __LINE__,__FILE__,i,j,rank+10,cbuffer[i][j]);
                 nerrs++;
             }
         }
     }
 
     err = ncmpi_close(ncid);
-    ERR
+    CHECK_ERR
 
     if (bufsize>0) free(cbuffer[0]);
     for (i=0; i<nreqs; i++) free(buffer[i]);
@@ -604,6 +608,6 @@ int main(int argc, char** argv)
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
