@@ -12,7 +12,7 @@
 ! 
 ! i=longitude, j=latitude, k=level
 !
-! $Id: mcoll_testf.f90 2512 2016-09-29 01:29:37Z wkliao $
+! $Id: mcoll_testf.f90 3341 2017-08-25 22:29:08Z wkliao $
 !
 !=============================================================================
 
@@ -151,7 +151,7 @@
                       TOTSIZ_3D, wrt_l)
       if (ierr .NE. NF90_NOERR) then
           write(6,*) trim(nf90mpi_strerror(ierr))
-          goto 999
+          stop 2
       endif
 !!!   Write (6,*) wrt_l(1), wrt_l(2)
 
