@@ -2,7 +2,7 @@
  *  Copyright (C) 2013, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  */
-/* $Id: test_subfile.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: test_subfile.c 3555 2017-11-22 18:01:35Z wkliao $ */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -15,8 +15,6 @@
 
 #include <testutils.h>
 
-#define MAXLINE 128
-
 /* The file name is taken as a command-line argument. */
 
 /* Measures the I/O bandwidth for writing/reading a 3D
@@ -24,13 +22,8 @@
    in row-major (C) order.
    Note that the file access pattern is noncontiguous.
 
-   Array size 128^3. For other array sizes, change array_of_gsizes below.*/
-#define TEST_HANDLE_ERR(status)                         \
-        if ((status) != NC_NOERR) {                     \
-            printf("Error at line %d (%s)\n", __LINE__, \
-                   ncmpi_strerror((status)) );          \
-            nerrs++;                                     \
-        }                                               \
+   Array size 128^3. For other array sizes, change array_of_gsizes below.
+*/
 
 int main(int argc, char **argv)
 {
@@ -41,9 +34,9 @@ int main(int argc, char **argv)
     int nprocs, len, **buf, rank;
     MPI_Offset bufcount;
     int array_of_psizes[3];
-    int status;
+    int err;
     MPI_Offset array_of_starts[3];
-    char *fbasename = NULL, *fbasename1 = NULL, filename[256];
+    char *fbasename=NULL;
     char dimname[20], varname[20];
     int ncid, dimids0[3], rank_dim[3], *varid=NULL;
     MPI_Info info=MPI_INFO_NULL, info_used=MPI_INFO_NULL;
@@ -51,7 +44,7 @@ int main(int argc, char **argv)
     MPI_Offset *bufcount_list;
     int ndims=3, nvars=1, ngatts, unlimdimid;
     MPI_Datatype *datatype_list;
-    int length = 128; /* 8MB per proc */
+    int length = 8;
     double stim, write_tim, new_write_tim, write_bw;
     double read_tim, new_read_tim, read_bw;
     double open_tim, new_open_tim;
@@ -67,8 +60,8 @@ int main(int argc, char **argv)
 
     /* process 0 takes the file name as a command-line argument and
        broadcasts it to other processes */
-    if (!rank) {
-	while ((opt = getopt(argc, argv, "f:s:rp:n:l:")) != EOF) {
+    if (rank == 0) {
+	while ((opt = getopt(argc, argv, "f:s:p:n:l:r")) != EOF) {
 	    switch (opt) {
 	    case 'f': fbasename = optarg;
 		break;
@@ -88,30 +81,29 @@ int main(int argc, char **argv)
 	}
 	if (fbasename == NULL) {
 	    fprintf(stderr, "\n*#  Usage: test_subfile -f pathname -s num_sf -p par_dim_id \n\n");
-	    MPI_Abort(MPI_COMM_WORLD, 1);
+	    nerrs++;
 	}
-
-	fbasename1 = (char *) malloc (MAXLINE);
-	sprintf(fbasename1, "%s", fbasename);
-	len = strlen(fbasename1);
+    }
+    MPI_Bcast(&nerrs, 1, MPI_INT, 0, MPI_COMM_WORLD);
+    if (nerrs > 0) {
+        MPI_Finalize();
+        return 1;
+    }
+        
+    if (rank == 0) {
+	len = strlen(fbasename);
 	MPI_Bcast(&len, 1, MPI_INT, 0, MPI_COMM_WORLD);
-	MPI_Bcast(fbasename, len+1, MPI_CHAR, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&num_sf, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&par_dim_id, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&nvars, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&do_read, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&length, 1, MPI_INT, 0, MPI_COMM_WORLD);
     }
     else {
-	fbasename1 = (char *) malloc (MAXLINE);
 	MPI_Bcast(&len, 1, MPI_INT, 0, MPI_COMM_WORLD);
-	MPI_Bcast(fbasename1, len+1, MPI_CHAR, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&num_sf, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&par_dim_id, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&nvars, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&do_read, 1, MPI_INT, 0, MPI_COMM_WORLD);
-        MPI_Bcast(&length, 1, MPI_INT, 0, MPI_COMM_WORLD);
+	fbasename = (char *) malloc(len+1);
     }
+    MPI_Bcast(fbasename, len+1, MPI_CHAR, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&num_sf, 1, MPI_INT, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&par_dim_id, 1, MPI_INT, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&nvars, 1, MPI_INT, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&do_read, 1, MPI_INT, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&length, 1, MPI_INT, 0, MPI_COMM_WORLD);
 
     if (rank == 0) {
         char *cmd_str = (char*)malloc(strlen(argv[0]) + 256);
@@ -125,39 +117,39 @@ int main(int argc, char **argv)
     buf = (int **)malloc(nvars*sizeof(int*));
     if (buf == NULL){
         printf("buf malloc error\n");
-        return 0;
+        nerrs++; goto fn_exit;
     }
     bufcount_list = (MPI_Offset *)malloc(nvars*sizeof(MPI_Offset));
     if (bufcount_list == NULL){
         printf("bufcount_list malloc error\n");
-        return 0;
+        nerrs++; goto fn_exit;
     }
     starts_list = (MPI_Offset **)malloc(nvars*sizeof(MPI_Offset *));
     if (starts_list== NULL){
         printf("starts_list malloc error\n");
-        return 0;
+        nerrs++; goto fn_exit;
     }
     count_list = (MPI_Offset **)malloc(nvars*sizeof(MPI_Offset *));
     if (count_list == NULL){
         printf("count_list malloc error\n");
-        return 0;
+        nerrs++; goto fn_exit;
     }
     datatype_list = (MPI_Datatype*)malloc(nvars*sizeof(MPI_Datatype));
     if (datatype_list == NULL){
         printf("count_list malloc error\n");
-        return 0;
+        nerrs++; goto fn_exit;
     }
 
     for (i=0; i<nvars; i++) {
 	starts_list[i] = (MPI_Offset *)malloc(ndims*sizeof(MPI_Offset));
 	if (starts_list[i] == NULL){
 	    printf("starts_list[%d] malloc error\n", i);
-	    return 0;
+	    nerrs++; goto fn_exit;
 	}
 	count_list[i] = (MPI_Offset *)malloc(ndims*sizeof(MPI_Offset));
 	if (count_list[i] == NULL){
 	    printf("count_list[%d] malloc error\n", i);
-	    return 0;
+	    nerrs++; goto fn_exit;
 	}
     }
 
@@ -197,7 +189,7 @@ int main(int argc, char **argv)
 	buf[i] = (int *) malloc(bufcount * sizeof(int));
 	if (buf[i] == NULL){
 	    printf("buf[i]malloc error\n");
-	    return 0;
+	    nerrs++; goto fn_exit;
 	}
 
 	for (j=0; j<bufcount; j++)
@@ -209,15 +201,14 @@ int main(int argc, char **argv)
     char tmp[10];
     sprintf(tmp, "%d", num_sf);
     MPI_Info_set(info, "nc_num_subfiles", tmp);
-
-    sprintf(filename, "%s.%d.%d.%d.nc", fbasename1, length, 1, 0);
+    MPI_Info_set(info, "pnetcdf_subfiling", "enable");
 
     if (do_read == 1) goto read;
 
     stim = MPI_Wtime();
-    status = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER|NC_64BIT_DATA,
-                          info, &ncid);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_create(MPI_COMM_WORLD, fbasename, NC_CLOBBER|NC_64BIT_DATA,
+                       info, &ncid);
+    CHECK_ERR
 
     open_tim = MPI_Wtime() - stim;
 
@@ -229,35 +220,35 @@ int main(int argc, char **argv)
     /* define dimensions */
     for (i=0; i<ndims; i++){
         sprintf(dimname, "dim0_%d", i);
-        status = ncmpi_def_dim(ncid, dimname, array_of_gsizes[i], &dimids0[i]);
-        TEST_HANDLE_ERR(status)
+        err = ncmpi_def_dim(ncid, dimname, array_of_gsizes[i], &dimids0[i]);
+        CHECK_ERR
     }
 
     /* define variables */
     varid = (int *)malloc(nvars*sizeof(int));
     for (i=0; i<nvars; i++) {
 	sprintf(varname, "var0_%d", i);
-	status = ncmpi_def_var(ncid, varname, NC_INT, ndims, dimids0, &varid[i]);
-	TEST_HANDLE_ERR(status)
+	err = ncmpi_def_var(ncid, varname, NC_INT, ndims, dimids0, &varid[i]);
+	CHECK_ERR
     }
 
     if (par_dim_id != 0) {
         for (i=0; i<nvars; i++) {
-            status = ncmpi_put_att_int(ncid, varid[i], "par_dim_id",
-                                       NC_INT, 1, &dimids0[par_dim_id]);
-	    TEST_HANDLE_ERR(status)
+            err = ncmpi_put_att_int(ncid, varid[i], "par_dim_id",
+                                    NC_INT, 1, &dimids0[par_dim_id]);
+	    CHECK_ERR
         }
     }
 
     /* set all non-record variable to be subfiled */
     /*
     MPI_Info_set(info, "nc_num_subfiles", "2");
-    status = ncmpi_set_var_info(ncid, varid, info);
-    TEST_HANDLE_ERR(status);
+    err = ncmpi_set_var_info(ncid, varid, info);
+    CHECK_ERR
     */
 
-    status = ncmpi_enddef(ncid);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_enddef(ncid);
+    CHECK_ERR
 
     /* test ncmpi_inq_var() */
     for (i=0; i<nvars; i++) {
@@ -265,29 +256,33 @@ int main(int argc, char **argv)
         nc_type typep;
         int ndimsp, dimids[3], nattsp;
 
-        status = ncmpi_inq_var(ncid, varid[i], name, &typep, &ndimsp, dimids,
-                               &nattsp);
-        TEST_HANDLE_ERR(status)
+        err = ncmpi_inq_var(ncid, varid[i], name, &typep, &ndimsp, dimids,
+                            &nattsp);
+        CHECK_ERR
 
 	sprintf(varname, "var0_%d", i);
         if (strcmp(name, varname)) {
-            printf("Error: unexpected var[%d] name %s, should be %s\n",i,name,varname);
+            printf("Error at line %d in %s: unexpected var[%d] name %s, should be %s\n",
+            __LINE__,__FILE__,i,name,varname);
             nerrs++;
             continue;
         }
         if (typep != NC_INT) {
-            printf("Error: unexpected var[%d] type %d, should be %d\n",i,typep,NC_INT);
+            printf("Error at line %d in %s: unexpected var[%d] type %d, should be %d\n",
+            __LINE__,__FILE__,i,typep,NC_INT);
             nerrs++;
             continue;
         }
         if (ndimsp != ndims) {
-            printf("Error: unexpected var[%d] ndims %d, should be %d\n",i,ndimsp,ndims);
+            printf("Error at line %d in %s: unexpected var[%d] ndims %d, should be %d\n",
+            __LINE__,__FILE__,i,ndimsp,ndims);
             nerrs++;
             continue;
         }
         for (j=0; j<ndims; j++) {
             if (dimids[j] != dimids0[j]) {
-                printf("Error: unexpected var[%d] dimids[%d] %d, should be %d\n",i,j,dimids0[j],dimids[j]);
+                printf("Error at line %d in %s: unexpected var[%d] dimids[%d] %d, should be %d\n",
+            __LINE__,__FILE__,i,j,dimids0[j],dimids[j]);
                 nerrs++;
                 continue;
             }
@@ -303,11 +298,11 @@ int main(int argc, char **argv)
 #endif
     stim = MPI_Wtime();
     for (i=0; i<nvars; i++) {
-        status = ncmpi_put_vara_all(ncid, varid[i],
-                                    starts_list[i], count_list[i],
-                                    buf[i],
-                                    bufcount_list[i], MPI_INT);
-        TEST_HANDLE_ERR(status)
+        err = ncmpi_put_vara_all(ncid, varid[i],
+                                 starts_list[i], count_list[i],
+                                 buf[i],
+                                 bufcount_list[i], MPI_INT);
+        CHECK_ERR
     }
     write_tim = MPI_Wtime() - stim;
 
@@ -320,12 +315,12 @@ int main(int argc, char **argv)
         printf("Collective write time = %f sec, Collective write bandwidth = %f Mbytes/sec\n", new_write_tim, write_bw);
     }
 
-    status = ncmpi_inq_file_info(ncid, &info_used);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_inq_file_info(ncid, &info_used);
+    CHECK_ERR
 
     stim = MPI_Wtime();
-    status = ncmpi_close(ncid);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_close(ncid);
+    CHECK_ERR
     close_tim = MPI_Wtime() - stim;
 
     MPI_Allreduce(&close_tim, &new_close_tim, 1, MPI_DOUBLE, MPI_MAX,
@@ -338,8 +333,8 @@ int main(int argc, char **argv)
     goto end;
 
 read:
-    status = ncmpi_open(MPI_COMM_WORLD, filename, NC_NOWRITE, MPI_INFO_NULL, &ncid);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_open(MPI_COMM_WORLD, fbasename, NC_NOWRITE, info, &ncid);
+    CHECK_ERR
 
     stim = MPI_Wtime();
 
@@ -348,14 +343,14 @@ read:
      * Add dataset definitions for output dataset.
      */
 
-    status = ncmpi_inq(ncid, &ndims, &nvars, &ngatts, &unlimdimid);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_inq(ncid, &ndims, &nvars, &ngatts, &unlimdimid);
+    CHECK_ERR
 
     for (i=0; i<nvars; i++) {
-        status = ncmpi_get_vara_all(ncid, i,
-                                    starts_list[i], count_list[i],
-                                    buf[i], bufcount_list[i], MPI_INT);
-        TEST_HANDLE_ERR(status)
+        err = ncmpi_get_vara_all(ncid, i,
+                                 starts_list[i], count_list[i],
+                                 buf[i], bufcount_list[i], MPI_INT);
+        CHECK_ERR
     }
     read_tim = MPI_Wtime() - stim;
 
@@ -367,11 +362,11 @@ read:
         printf("Collective read time = %f sec, Collective read bandwidth = %f Mbytes/sec\n", new_read_tim, read_bw);
     }
 
-    status = ncmpi_inq_file_info(ncid, &info_used);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_inq_file_info(ncid, &info_used);
+    CHECK_ERR
 
-    status = ncmpi_close(ncid);
-    TEST_HANDLE_ERR(status)
+    err = ncmpi_close(ncid);
+    CHECK_ERR
 
 end:
     if (info      != MPI_INFO_NULL) MPI_Info_free(&info);
@@ -388,14 +383,18 @@ end:
     if (!do_read) free(varid);
     free(starts_list);
     free(count_list);
-    free(fbasename1);
+    if (rank > 0) free(fbasename);
 
     MPI_Offset malloc_size, sum_size;
-    int err, nfiles, ncids[10];
+    int nfiles, ncids[10];
+
+    /* NULL argument test */
+    err = ncmpi_inq_files_opened(NULL, NULL);
+    EXP_ERR(NC_EINVAL)
 
     /* check if there are files still left opened */
     err = ncmpi_inq_files_opened(&nfiles, ncids);
-    TEST_HANDLE_ERR(err)
+    CHECK_ERR
     if (nfiles > 0) printf("nfiles %d still opened\n",nfiles);
 
     /* check for any PnetCDF internal malloc residues */
@@ -413,7 +412,7 @@ end:
         else       printf(PASS_STR);
     }
 
+fn_exit:
     MPI_Finalize();
-
-    return 0;
+    return (nerrs > 0);
 }
