@@ -2,7 +2,7 @@
 !   Copyright (C) 2015, Northwestern University
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: buftype_freef.f 2638 2016-11-18 14:51:02Z wkliao $
+! $Id: buftype_freef.f 3341 2017-08-25 22:29:08Z wkliao $
 
 ! This example tests if PnetCDF duplicates the MPI derived data type supplied
 ! by the user, when calling the flexible APIs. It tests a PnetCDF bug
@@ -37,7 +37,7 @@
               write(6,*) message(1:XTRIM(message)), nfmpi_strerror(err)
               msg = '*** TESTING F77 buftype_freef.f for flexible API '
               call pass_fail(1, msg)
-              call MPI_Abort(MPI_COMM_WORLD, -1, err)
+              STOP 2
           end if
       end ! subroutine check
 
@@ -174,5 +174,7 @@
           endif
 
  999      call MPI_Finalize(ierr)
+          if (nerrs .GT. 0) stop 2
+
       end ! program main
 
