@@ -2,7 +2,7 @@
  *  Copyright (C) 2015, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  *
- *  $Id: check_striping.c 2744 2016-12-28 16:25:22Z wkliao $
+ *  $Id: check_striping.c 3341 2017-08-25 22:29:08Z wkliao $
  */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -28,8 +28,6 @@
 
 #include <testutils.h>
 
-#define ERR {if(err!=NC_NOERR){nerrs++;printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));}}
-
 int main(int argc, char** argv) {
     char filename[256];
     int rank, nprocs, err, nerrs=0, ncid, cmode;
@@ -42,7 +40,7 @@ int main(int argc, char** argv) {
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -55,10 +53,10 @@ int main(int argc, char** argv) {
     }
 
     cmode = NC_CLOBBER;
-    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid); ERR
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid); CHECK_ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
-    err = ncmpi_inq_striping(ncid, &striping_size, &striping_count); ERR
+    err = ncmpi_inq_striping(ncid, &striping_size, &striping_count); CHECK_ERR
 
     root_striping_size  = striping_size;
     root_striping_count = striping_count;
@@ -67,13 +65,13 @@ int main(int argc, char** argv) {
     err = MPI_Bcast(&root_striping_count, 1, MPI_INT, 0, MPI_COMM_WORLD);
     MPI_ERR(err)
     if (root_striping_size != striping_size) {
-        printf("Error at PE %2d: inconsistent striping_size (root=%d local=%d)\n",
-               rank, root_striping_size, striping_size);
+        printf("Error at line %d in %s: inconsistent striping_size (root=%d local=%d)\n",
+               __LINE__,__FILE__, root_striping_size, striping_size);
         nerrs++;
     }
     if (root_striping_count != striping_count) {
-        printf("Error at PE %2d: inconsistent striping_count (root=%d local=%d)\n",
-               rank, root_striping_count, striping_count);
+        printf("Error at line %d in %s: inconsistent striping_count (root=%d local=%d)\n",
+               __LINE__,__FILE__, root_striping_count, striping_count);
         nerrs++;
     }
 /*
@@ -81,7 +79,7 @@ int main(int argc, char** argv) {
         printf("Success: striping_size=%d striping_count=%d\n",striping_size,striping_count);
 */
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* check if PnetCDF freed all internal malloc */
     MPI_Offset malloc_size, sum_size;
@@ -99,6 +97,6 @@ int main(int argc, char** argv) {
         else       printf(PASS_STR);
     }
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
