@@ -2,7 +2,7 @@
  *  Copyright (C) 2003, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  *
- *  $Id: collective_error.c 2744 2016-12-28 16:25:22Z wkliao $
+ *  $Id: collective_error.c 3341 2017-08-25 22:29:08Z wkliao $
  */
 
 /* This test program checks whether a collective API can be nicely aborted
@@ -30,15 +30,6 @@
 
 #include <testutils.h>
 
-#define ERR { if (err!=NC_NOERR){printf("PE %d: error at line %d (%s)\n",rank,__LINE__,ncmpi_strerror(err)); nerrs++;}}
-
-#define EXP_ERR(e) { \
-    if (err!=e) { \
-        printf("PE %d: error at line %d expecting %s but got %s\n",rank,__LINE__,nc_err_code_name(e),nc_err_code_name(err)); \
-        nerrs++; \
-    } \
-}
-
 static
 int test_collective_error(char *filename, int safe_mode)
 {
@@ -51,10 +42,10 @@ int test_collective_error(char *filename, int safe_mode)
     MPI_Comm_size(MPI_COMM_WORLD, &nproc);
 
     /* Create a 2 element vector of doubles */
-    err = ncmpi_create(comm, filename, NC_CLOBBER, MPI_INFO_NULL, &ncid); ERR
-    err = ncmpi_def_dim(ncid, "dim", 2, &dimids[0]); ERR
-    err = ncmpi_def_var(ncid, "var", NC_DOUBLE, 1, dimids, &varid); ERR
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_create(comm, filename, NC_CLOBBER, MPI_INFO_NULL, &ncid); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "dim", 2, &dimids[0]); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var", NC_DOUBLE, 1, dimids, &varid); CHECK_ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     if (rank == 0) {
         start[0] = 0;
@@ -82,13 +73,13 @@ int test_collective_error(char *filename, int safe_mode)
 
     /* check if user put buffer contents altered */
     if (buf[0] != 1.0) {
-        printf("Error: user put buffer[%d] altered from %f to %f\n",
-               0, 1.0, buf[0]);
+        printf("Error at line %d in %s: user put buffer[%d] altered from %f to %f\n",
+               __LINE__,__FILE__,0, 1.0, buf[0]);
         nerrs++;
     }
     if (buf[1] != 2.0) {
-        printf("Error: user put buffer[%d] altered from %f to %f\n",
-               1, 2.0, buf[1]);
+        printf("Error at line %d in %s: user put buffer[%d] altered from %f to %f\n",
+               __LINE__,__FILE__,1, 2.0, buf[1]);
         nerrs++;
     }
 
@@ -98,13 +89,13 @@ int test_collective_error(char *filename, int safe_mode)
 
     /* check if user put buffer contents altered */
     if (buf[0] != 1.0) {
-        printf("Error: user put buffer[%d] altered from %f to %f\n",
-               0, 1.0, buf[0]);
+        printf("Error at line %d in %s: user put buffer[%d] altered from %f to %f\n",
+               __LINE__,__FILE__,0, 1.0, buf[0]);
         nerrs++;
     }
     if (buf[1] != 2.0) {
-        printf("Error: user put buffer[%d] altered from %f to %f\n",
-               1, 2.0, buf[1]);
+        printf("Error at line %d in %s: user put buffer[%d] altered from %f to %f\n",
+               __LINE__,__FILE__,1, 2.0, buf[1]);
         nerrs++;
     }
 
@@ -114,17 +105,17 @@ int test_collective_error(char *filename, int safe_mode)
     else
         EXP_ERR(NC_NOERR)
 
-    err = ncmpi_wait_all(ncid, 1, &req, &status); ERR
+    err = ncmpi_wait_all(ncid, 1, &req, &status); CHECK_ERR
 
     /* check if user put buffer contents altered */
     if (buf[0] != 1.0) {
-        printf("Error: user put buffer[%d] altered from %f to %f\n",
-               0, 1.0, buf[0]);
+        printf("Error at line %d in %s: user put buffer[%d] altered from %f to %f\n",
+               __LINE__,__FILE__,0, 1.0, buf[0]);
         nerrs++;
     }
     if (buf[1] != 2.0) {
-        printf("Error: user put buffer[%d] altered from %f to %f\n",
-               1, 2.0, buf[1]);
+        printf("Error at line %d in %s: user put buffer[%d] altered from %f to %f\n",
+               __LINE__,__FILE__,1, 2.0, buf[1]);
         nerrs++;
     }
 
@@ -143,9 +134,9 @@ int test_collective_error(char *filename, int safe_mode)
     else
         EXP_ERR(NC_NOERR)
 
-    err = ncmpi_wait_all(ncid, 1, &req, &status); ERR
+    err = ncmpi_wait_all(ncid, 1, &req, &status); CHECK_ERR
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -161,7 +152,7 @@ int main(int argc, char *argv[])
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -198,5 +189,5 @@ int main(int argc, char *argv[])
     }
 
     MPI_Finalize();
-    return (nerrs == 0) ? 0 : 1;
+    return (nerrs > 0);
 }
