@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: flexible_varm.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: flexible_varm.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -56,8 +56,6 @@
 #define NX 4
 #define GHOST 2
 
-#define ERR {if(err!=NC_NOERR){printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err)); nerrs++;}}
-
 #define INIT_PUT_BUF \
     for (i=0; i<array_of_sizes[0]; i++) { \
         for (j=0; j<array_of_sizes[1]; j++) { \
@@ -75,15 +73,15 @@
             if (i < GHOST || GHOST+array_of_subsizes[0] <= i || \
                 j < GHOST || GHOST+array_of_subsizes[1] <= j) { \
                 if (buf[i][j] != -1) { \
-                    printf("Error: put buffer altered buffer[%d][%d]=%d\n", \
-                           i,j,buf[i][j]); \
+                    printf("Error at line %d in %s: put buffer altered buffer[%d][%d]=%d\n", \
+                           __LINE__,__FILE__,i,j,buf[i][j]); \
                     nerrs++; \
                 } \
             } \
             else { \
                 if (buf[i][j] != (i-GHOST)*array_of_subsizes[1]+(j-GHOST)) { \
-                    printf("Error: put buffer altered buffer[%d][%d]=%d\n", \
-                           i,j,buf[i][j]); \
+                    printf("Error at line %d in %s: put buffer altered buffer[%d][%d]=%d\n", \
+                           __LINE__,__FILE__,i,j,buf[i][j]); \
                     nerrs++; \
                 } \
             } \
@@ -133,7 +131,7 @@ int main(int argc, char** argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -149,15 +147,15 @@ int main(int argc, char** argv)
     /* create a new file for writing ----------------------------------------*/
     cmode = NC_CLOBBER | NC_64BIT_DATA;
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    ERR
+    CHECK_ERR
 
     /* define 2 dimensions */
-    err = ncmpi_def_dim(ncid, "Y", NY,        &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "X", NX*nprocs, &dimid[1]); ERR
+    err = ncmpi_def_dim(ncid, "Y", NY,        &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "X", NX*nprocs, &dimid[1]); CHECK_ERR
 
     /* define a variable of size NY * (NX * nprocs) */
-    err = ncmpi_def_var(ncid, "var", NC_DOUBLE, 2, dimid, &varid); ERR
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_def_var(ncid, "var", NC_DOUBLE, 2, dimid, &varid); CHECK_ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
      start[0] = 0;  start[1] = NX * rank;
      count[0] = NY; count[1] = NX;
@@ -180,7 +178,7 @@ int main(int argc, char** argv)
     INIT_PUT_BUF
     err = ncmpi_put_varm_all(ncid, varid, start, count, stride, imap, buf,
                              1, subarray);
-    ERR
+    CHECK_ERR
 
     /* check the contents of put buffer */
     CHECK_PUT_BUF
@@ -190,9 +188,9 @@ int main(int argc, char** argv)
     INIT_PUT_BUF
     err = ncmpi_iput_varm(ncid, varid, start, count, stride, imap, buf,
                           1, subarray, &req);
-    ERR
-    err = ncmpi_wait_all(ncid, 1, &req, &status); ERR
-    err = status; ERR
+    CHECK_ERR
+    err = ncmpi_wait_all(ncid, 1, &req, &status); CHECK_ERR
+    err = status; CHECK_ERR
 
     /* check the contents of put buffer */
     CHECK_PUT_BUF
@@ -204,7 +202,7 @@ int main(int argc, char** argv)
     /* calling a blocking flexible API */
     err = ncmpi_get_varm_all(ncid, varid, start, count, stride, imap, buf,
                              1, subarray);
-    ERR
+    CHECK_ERR
 
     /* check the contents of get buffer */
     CHECK_GET_BUF
@@ -216,16 +214,16 @@ int main(int argc, char** argv)
     /* calling a blocking flexible API */
     err = ncmpi_iget_varm(ncid, varid, start, count, stride, imap, buf,
                           1, subarray, &req);
-    ERR
-    err = ncmpi_wait_all(ncid, 1, &req, &status); ERR
-    err = status; ERR
+    CHECK_ERR
+    err = ncmpi_wait_all(ncid, 1, &req, &status); CHECK_ERR
+    err = status; CHECK_ERR
 
     /* check the contents of get buffer */
     CHECK_GET_BUF
 
     MPI_Type_free(&subarray);
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* check if PnetCDF freed all internal malloc */
     MPI_Offset malloc_size, sum_size;
@@ -244,6 +242,6 @@ int main(int argc, char** argv)
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
