@@ -2,14 +2,14 @@
 !   Copyright (C) 2014, Northwestern University and Argonne National Laboratory
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: inq_num_varsf.f90 2638 2016-11-18 14:51:02Z wkliao $
+! $Id: inq_num_varsf.f90 3422 2017-09-25 05:42:52Z wkliao $
 
 !
 ! This program tests if one can get the number of record variables and
 ! fixed-size variables correctly. It first defines some number of
 ! fixed-size and record variables and then calls the APIs
 !     ncmpi_inq_num_rec_vars() and ncmpi_inq_num_fix_vars()
-! to varify if the numbers are correct.
+! to verify if the numbers are correct.
 !
 ! The compile and run commands are given below. This program is to be
 ! run on one MPI process.
@@ -165,5 +165,7 @@
           endif
 
  999      call MPI_Finalize(ierr)
+          if (nerrs .GT. 0) stop 2
+
       end program main
 
