@@ -2,7 +2,7 @@
  *  Copyright (C) 2014, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  *
- *  $Id: inq_recsize.c 2744 2016-12-28 16:25:22Z wkliao $
+ *  $Id: inq_recsize.c 3555 2017-11-22 18:01:35Z wkliao $
  */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -10,7 +10,7 @@
  * This program tests if one can get the size of record block correctly. The
  * record block size is the sum of individual record of all record variables.
  * It first defines some number of record and fixed-size variables and then
- * calls the API ncmpi_inq_recsize() and varify if the numbers are correct.
+ * calls the API ncmpi_inq_recsize() and verify if the numbers are correct.
  *
  * The compile and run commands are given below. This program is to be run on
  * one MPI process.
@@ -29,11 +29,9 @@
 
 #include <testutils.h>
 
-#define ERR {if(err!=NC_NOERR)printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));}
-
 int main(int argc, char** argv) {
     char filename[256];
-    int nerrs, rank, nprocs, err;
+    int nerrs=0, rank, nprocs, err;
     int ncid, cmode, varid[7], dimid[3];
     MPI_Offset expected_recsize, recsize;
     MPI_Info info=MPI_INFO_NULL;
@@ -60,40 +58,44 @@ int main(int argc, char** argv) {
 
     /* create a new file for writing ----------------------------------------*/
     cmode = NC_CLOBBER;
-    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, info, &ncid); ERR
+    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, info, &ncid); CHECK_ERR
 
     /* define dimension and variable */
-    err = ncmpi_def_dim(ncid, "REC_DIM", NC_UNLIMITED, &dimid[0]); ERR
-    err = ncmpi_def_dim(ncid, "Y",       2,            &dimid[1]); ERR
-    err = ncmpi_def_dim(ncid, "X",       10,           &dimid[2]); ERR
+    err = ncmpi_def_dim(ncid, "REC_DIM", NC_UNLIMITED, &dimid[0]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "Y",       2,            &dimid[1]); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "X",       10,           &dimid[2]); CHECK_ERR
 
     nerrs = 0;
     expected_recsize = 0;
 
     /* define some record variables */
-    err = ncmpi_def_var(ncid, "REC_VAR_1", NC_INT, 1, dimid, &varid[0]); ERR
+    err = ncmpi_def_var(ncid, "REC_VAR_1", NC_INT, 1, dimid, &varid[0]); CHECK_ERR
     expected_recsize += sizeof(int);
-    err = ncmpi_def_var(ncid, "REC_VAR_2", NC_INT, 3, dimid, &varid[1]); ERR
+    err = ncmpi_def_var(ncid, "REC_VAR_2", NC_INT, 3, dimid, &varid[1]); CHECK_ERR
     expected_recsize += 2 * 10 * sizeof(int);
-    err = ncmpi_def_var(ncid, "REC_VAR_3", NC_INT, 2, dimid, &varid[2]); ERR
+    err = ncmpi_def_var(ncid, "REC_VAR_3", NC_INT, 2, dimid, &varid[2]); CHECK_ERR
     expected_recsize += 2 * sizeof(int);
-    err = ncmpi_def_var(ncid, "REC_VAR_4", NC_INT, 1, dimid, &varid[3]); ERR
+    err = ncmpi_def_var(ncid, "REC_VAR_4", NC_INT, 1, dimid, &varid[3]); CHECK_ERR
     expected_recsize += sizeof(int);
 
     /* define some fixed-size variables */
-    err = ncmpi_def_var(ncid, "FIX_VAR_1", NC_INT, 2, dimid+1, &varid[4]); ERR
-    err = ncmpi_def_var(ncid, "FIX_VAR_2", NC_INT, 1, dimid+1, &varid[5]); ERR
-    err = ncmpi_def_var(ncid, "FIX_VAR_3", NC_INT, 1, dimid+2, &varid[6]); ERR
+    err = ncmpi_def_var(ncid, "FIX_VAR_1", NC_INT, 2, dimid+1, &varid[4]); CHECK_ERR
+    err = ncmpi_def_var(ncid, "FIX_VAR_2", NC_INT, 1, dimid+1, &varid[5]); CHECK_ERR
+    err = ncmpi_def_var(ncid, "FIX_VAR_3", NC_INT, 1, dimid+2, &varid[6]); CHECK_ERR
 
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
-    err = ncmpi_inq_recsize(ncid, &recsize); ERR
+    /* NULL argument test */
+    err = ncmpi_inq_recsize(ncid, NULL); CHECK_ERR
+
+    err = ncmpi_inq_recsize(ncid, &recsize); CHECK_ERR
     if (expected_recsize != recsize) {
-        printf("Error at line %d: expecting record size %lld but got %lld\n", __LINE__,expected_recsize, recsize);
+        printf("Error at line %d in %s: expecting record size %lld but got %lld\n",
+        __LINE__,__FILE__,expected_recsize, recsize);
         nerrs++;
     }
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* check if PnetCDF freed all internal malloc */
     MPI_Offset malloc_size, sum_size;
@@ -113,6 +115,6 @@ int main(int argc, char** argv) {
 
 fn_exit:
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
