@@ -2,13 +2,13 @@
 !   Copyright (C) 2014, Northwestern University and Argonne National Laboratory
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: inq_recsizef.f90 2638 2016-11-18 14:51:02Z wkliao $
+! $Id: inq_recsizef.f90 3422 2017-09-25 05:42:52Z wkliao $
 
 !
 ! This program tests if one can get the size of record block correctly.
 ! The record block size is the sum of individual record of all record
 ! variables. It first defines some number of record and fixed-size
-! variables and then calls the API ncmpi_inq_recsize() and varify if
+! variables and then calls the API ncmpi_inq_recsize() and verify if
 ! the numbers are ! correct.
 !
 ! The compile and run commands are given below. This program is to be
@@ -140,5 +140,7 @@
           endif
 
  999      call MPI_Finalize(ierr)
+          if (nerrs .GT. 0) stop 2
+
       end program main
 
