@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: modes.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: modes.c 3604 2017-12-16 09:21:02Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * This program tests if the correct error codes are returns given various
@@ -25,32 +25,31 @@
 
 #include <testutils.h>
 
-#define ERR {if(err!=NC_NOERR)printf("Error at line=%d: %s\n", __LINE__, ncmpi_strerror(err));}
-
-#define EXPECT_ERR(err_no) \
-    if (err != err_no) { \
-        nerrs++; \
-        printf("Error at line %d: expect error code %s but got %s\n", \
-               __LINE__,nc_err_code_name(err_no),nc_err_code_name(err)); \
-    }
-
 #define EXPECT_ERR2(err_no1, err_no2) \
     if (err != err_no1 && err != err_no2) { \
         nerrs++; \
-        printf("Error at line %d: expect error code %s but got %s\n", \
-               __LINE__,nc_err_code_name(err_no1),nc_err_code_name(err)); \
+        printf("Error at line %d in %s: expect error code %s or %s but got %s\n", \
+               __LINE__,__FILE__,ncmpi_strerrno(err_no1),ncmpi_strerrno(err_no2),ncmpi_strerrno(err)); \
     }
 
 static
 int check_modes(char *filename)
 {
-    int rank, err, nerrs=0;
-    int ncid, cmode;
+    int rank, err, nerrs=0, ncid, cmode;
+    char *path;
 
     MPI_Comm_rank(MPI_COMM_WORLD, &rank);
 
     /* delete the file and ignore error */
-    unlink(filename);
+    /* remove the file system type prefix name if there is any.
+     * For example, when filename = "lustre:/home/foo/testfile.nc", remove
+     * "lustre:" to make path = "/home/foo/testfile.nc" in open() below
+     */
+    path = strchr(filename, ':');
+    if (path == NULL) path = filename; /* no prefix */
+    else              path++;
+
+    if (rank == 0) unlink(path);
     MPI_Barrier(MPI_COMM_WORLD);
 
     /* create a new file and test various cmodes ----------------------------*/
@@ -60,16 +59,16 @@ int check_modes(char *filename)
     cmode |= NC_64BIT_OFFSET | NC_64BIT_DATA;
 
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    EXPECT_ERR(NC_EINVAL_CMODE)
+    EXP_ERR(NC_EINVAL_CMODE)
 
     /* The file should not be created */
     if (rank == 0) {
-        if (access(filename, F_OK) == 0) {
-            printf("Error at line %d: file (%s) should not be created\n",
-                   __LINE__, filename);
+        if (access(path, F_OK) == 0) {
+            printf("Error at line %d in %s: file (%s) should not be created\n",
+                   __LINE__,__FILE__, filename);
             nerrs++;
             /* delete the file and ignore error */
-            unlink(filename);
+            unlink(path);
         }
         /* else : file does not exist */
     }
@@ -78,43 +77,69 @@ int check_modes(char *filename)
     /* Collectively opening a non-existing file for read, expect error code
      * NC_ENOENT on all processes */
     err = ncmpi_open(MPI_COMM_WORLD, filename, NC_NOWRITE, MPI_INFO_NULL, &ncid);
-    /* older version of OpenMPI and MPICH may return MPI_ERR_IO instead of
-     * MPI_ERR_NO_SUCH_FILE */
-    EXPECT_ERR2(NC_ENOENT, NC_EFILE)
 
-    /* The file should not be created */
-    if (rank == 0) {
-        if (access(filename, F_OK) == 0) {
-            printf("Error at line %d: file (%s) should not be created\n",
-                   __LINE__, filename);
-            nerrs++;
-            /* delete the file and ignore error */
-            unlink(filename);
+    /* When using MVAPICH2 2.2, its Lustre driver adds O_CREAT to all open
+     * calls. This is considered a bug in an MPI-IO implementation. Due to this
+     * bug, the non-existing file will be created with zero-length and thus
+     * PnetCDF spews NC_ENOTNC */
+    if (err == NC_ENOTNC) {
+        /* ignore the error and delete the file */
+        if (rank == 0) unlink(path);
+    }
+    else {
+        /* older version of OpenMPI and MPICH may return MPI_ERR_IO instead of
+         * MPI_ERR_NO_SUCH_FILE */
+        EXPECT_ERR2(NC_ENOENT, NC_EFILE)
+
+        /* The file should not be created */
+        if (rank == 0) {
+            if (access(path, F_OK) == 0) {
+                printf("Error at line %d in %s: file (%s) should not be created\n",
+                       __LINE__,__FILE__, filename);
+                nerrs++;
+                /* delete the file and ignore error */
+                unlink(path);
+            }
+            /* else : file does not exist */
         }
-        /* else : file does not exist */
     }
     MPI_Barrier(MPI_COMM_WORLD);
 
     /* Collectively opening a non-existing file for write, expect error code
      * NC_ENOENT on all processes */
     err = ncmpi_open(MPI_COMM_WORLD, filename, NC_WRITE, MPI_INFO_NULL, &ncid);
-    /* older version of OpenMPI and MPICH may return MPI_ERR_IO instead of
-     * MPI_ERR_NO_SUCH_FILE */
-    EXPECT_ERR2(NC_ENOENT, NC_EFILE)
 
-    /* The file should not be created */
-    if (rank == 0) {
-        if (access(filename, F_OK) == 0) {
-            printf("Error at line %d: file (%s) should not be created\n",
-                   __LINE__, filename);
-            nerrs++;
-            /* delete the file and ignore error */
-            unlink(filename);
+    /* When using MVAPICH2 2.2, its Lustre driver adds O_CREAT to all open
+     * calls. This is considered a bug in an MPI-IO implementation. Due to this
+     * bug, the non-existing file will be created with zero-length and thus
+     * PnetCDF spews NC_ENOTNC */
+    if (err == NC_ENOTNC) {
+        /* ignore the error and delete the file */
+        if (rank == 0) unlink(path);
+    }
+    else {
+        /* older version of OpenMPI and MPICH may return MPI_ERR_IO instead of
+         * MPI_ERR_NO_SUCH_FILE */
+        EXPECT_ERR2(NC_ENOENT, NC_EFILE)
+
+        /* The file should not be created */
+        if (rank == 0) {
+            if (access(path, F_OK) == 0) {
+                printf("Error at line %d in %s: file (%s) should not be created\n",
+                       __LINE__,__FILE__, filename);
+                nerrs++;
+                /* delete the file and ignore error */
+                unlink(path);
+            }
+            /* else : file does not exist */
         }
-        /* else : file does not exist */
     }
     MPI_Barrier(MPI_COMM_WORLD);
 
+    err = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER, MPI_INFO_NULL, &ncid);
+    CHECK_ERR
+    err = ncmpi_close(ncid); CHECK_ERR
+
     return nerrs;
 }
 
@@ -129,11 +154,11 @@ int main(int argc, char** argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
-    if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
-    else           strcpy(filename, "testfile.nc");
-    MPI_Bcast(filename, 256, MPI_CHAR, 0, MPI_COMM_WORLD);
+    if (argc == 2) snprintf(filename, 256, "%s", argv[1]); 
+    else           strcpy(filename, "testfile.nc"); 
+    MPI_Bcast(filename, 256, MPI_CHAR, 0, MPI_COMM_WORLD); 
 
     if (rank == 0) {
         char *cmd_str = (char*)malloc(strlen(argv[0]) + 256);
@@ -167,6 +192,6 @@ int main(int argc, char** argv)
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
