@@ -2,30 +2,24 @@
  *  Copyright (C) 2003, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  *
- *  $Id: ncmpi_vars_null_stride.c 2744 2016-12-28 16:25:22Z wkliao $
+ *  $Id: ncmpi_vars_null_stride.c 3422 2017-09-25 05:42:52Z wkliao $
  */
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>  /* memset() */
+#include <string.h> /* memset() */
 #include <libgen.h> /* basename() */
 #include <mpi.h>
 #include <pnetcdf.h>
 
 #include <testutils.h>
 
-#define HANDLE_ERROR(err) { \
-    nerrs++; \
-    fprintf(stderr, "Error at line %d: %s\n", __LINE__, ncmpi_strerror(err)); \
-    goto fn_exit; \
-}
-
 /* check if user put buffer contents altered */
 #define CHECK_PUT_BUF \
     for (i=0; i<NY*NX; i++) { \
         if (buf[i] != rank+10) { \
-            printf("Error at line %d: user put buffer[%d] altered from %d to %d\n", \
-                   __LINE__, i, rank+10, buf[i]); \
+            printf("Error at line %d in %s: user put buffer[%d] altered from %d to %d\n", \
+                   __LINE__,__FILE__, i, rank+10, buf[i]); \
             nerrs++; \
         } \
     }
@@ -50,7 +44,7 @@ int main(int argc, char **argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -63,31 +57,31 @@ int main(int argc, char **argv)
     }
 
     err = ncmpi_create(MPI_COMM_WORLD, filename, 0, MPI_INFO_NULL, &ncid);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_def_dim(ncid, "X", nprocs*NX, &dimid[1]);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_def_var(ncid, "v0", NC_INT, ndims, dimid, &varid[0]);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_def_var(ncid, "v1", NC_INT, ndims, dimid, &varid[1]);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_def_var(ncid, "v2", NC_INT, ndims, dimid, &varid[2]);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_def_var(ncid, "v3", NC_INT, ndims, dimid, &varid[3]);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_def_var(ncid, "v4", NC_INT, ndims, dimid, &varid[4]);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_enddef(ncid);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     start[0] = 0;
     start[1] = rank*NX;
@@ -97,11 +91,11 @@ int main(int argc, char **argv)
     for (i=0; i<NY*NX; i++) buf[i] = rank+10;
 
     err = ncmpi_put_vara_int_all(ncid, varid[0], start, count, buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
     CHECK_PUT_BUF
 
     err = ncmpi_put_vars_int_all(ncid, varid[1], start, count, NULL, buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
     CHECK_PUT_BUF
 
     start[0] = 0;
@@ -111,22 +105,22 @@ int main(int argc, char **argv)
     stride[0] = 1;
     stride[1] = nprocs;
     err = ncmpi_put_vars_int_all(ncid, varid[2], start, count, stride, buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
     CHECK_PUT_BUF
 
     /* test bput_vars */
     err = ncmpi_buffer_attach(ncid, NY*NX*sizeof(int));
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     start[0] = 0;
     start[1] = rank*NX;
     count[0] = NY;
     count[1] = NX;
     err = ncmpi_bput_vars_int(ncid, varid[3], start, count, NULL, buf, &req);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_wait_all(ncid, 1, &req, NULL);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
     CHECK_PUT_BUF
 
     start[0] = 0;
@@ -136,20 +130,20 @@ int main(int argc, char **argv)
     stride[0] = 1;
     stride[1] = nprocs;
     err = ncmpi_bput_vars_int(ncid, varid[4], start, count, stride, buf, &req);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     err = ncmpi_wait_all(ncid, 1, &req, NULL);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
     CHECK_PUT_BUF
     free(buf);
 
     err = ncmpi_buffer_detach(ncid);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     buf = (int*) malloc((size_t)NY * NX * nprocs * sizeof(int));
     memset(buf, 0, (size_t)NY * NX * nprocs * sizeof(int));
     err = ncmpi_get_var_int_all(ncid, varid[0], buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     /* check read buffer contents */
     /*  v0 =
@@ -162,8 +156,8 @@ int main(int argc, char **argv)
         for (j=0; j<nprocs; j++) {
             for (k=0; k<NX; k++) {
                 if (buf[i*nprocs*NX+j*NX+k] != j+10) {
-                    printf("Error at line %d: expected buffer[%d]=%d but got %d\n",
-                           __LINE__,i*nprocs*NX+j*NX+k, j+10, buf[i*nprocs*NX+j*NX+k]);
+                    printf("Error at line %d in %s: expected buffer[%d]=%d but got %d\n",
+                           __LINE__,__FILE__,i*nprocs*NX+j*NX+k, j+10, buf[i*nprocs*NX+j*NX+k]);
                     nerrs++;
                 }
             }
@@ -172,7 +166,7 @@ int main(int argc, char **argv)
 
     memset(buf, 0, (size_t)NY * NX * nprocs * sizeof(int));
     err = ncmpi_get_var_int_all(ncid, varid[1], buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     /* check read buffer contents */
     /*  v1 =
@@ -185,8 +179,8 @@ int main(int argc, char **argv)
         for (j=0; j<nprocs; j++) {
             for (k=0; k<NX; k++) {
                 if (buf[i*nprocs*NX+j*NX+k] != j+10) {
-                    printf("Error at line %d: expected buffer[%d]=%d but got %d\n",
-                           __LINE__,i*nprocs*NX+j*NX+k, j+10, buf[i*nprocs*NX+j*NX+k]);
+                    printf("Error at line %d in %s: expected buffer[%d]=%d but got %d\n",
+                           __LINE__,__FILE__,i*nprocs*NX+j*NX+k, j+10, buf[i*nprocs*NX+j*NX+k]);
                     nerrs++;
                 }
             }
@@ -195,7 +189,7 @@ int main(int argc, char **argv)
 
     memset(buf, 0, (size_t)NY * NX * nprocs * sizeof(int));
     err = ncmpi_get_var_int_all(ncid, varid[2], buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     /* check read buffer contents */
     /*  v2 =
@@ -208,8 +202,8 @@ int main(int argc, char **argv)
         for (k=0; k<NX; k++) {
             for (j=0; j<nprocs; j++) {
                 if (buf[i*nprocs*NX+k*nprocs+j] != j+10) {
-                    printf("Error at line %d: expected buffer[%d]=%d but got %d\n",
-                           __LINE__,i*nprocs*NX+k*nprocs+j, j+10, buf[i*nprocs*NX+k*nprocs+j]);
+                    printf("Error at line %d in %s: expected buffer[%d]=%d but got %d\n",
+                           __LINE__,__FILE__,i*nprocs*NX+k*nprocs+j, j+10, buf[i*nprocs*NX+k*nprocs+j]);
                     nerrs++;
                 }
             }
@@ -218,7 +212,7 @@ int main(int argc, char **argv)
 
     memset(buf, 0, (size_t)NY * NX * nprocs * sizeof(int));
     err = ncmpi_get_var_int_all(ncid, varid[3], buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     /* check read buffer contents */
     /*  v3 =
@@ -231,8 +225,8 @@ int main(int argc, char **argv)
         for (j=0; j<nprocs; j++) {
             for (k=0; k<NX; k++) {
                 if (buf[i*nprocs*NX+j*NX+k] != j+10) {
-                    printf("Error at line %d: expected buffer[%d]=%d but got %d\n",
-                           __LINE__,i*nprocs*NX+j*NX+k, j+10, buf[i*nprocs*NX+j*NX+k]);
+                    printf("Error at line %d in %s: expected buffer[%d]=%d but got %d\n",
+                           __LINE__,__FILE__,i*nprocs*NX+j*NX+k, j+10, buf[i*nprocs*NX+j*NX+k]);
                     nerrs++;
                 }
             }
@@ -241,7 +235,7 @@ int main(int argc, char **argv)
 
     memset(buf, 0, (size_t)NY * NX * nprocs * sizeof(int));
     err = ncmpi_get_var_int_all(ncid, varid[4], buf);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     /* check read buffer contents */
     /*  v4 =
@@ -254,8 +248,8 @@ int main(int argc, char **argv)
         for (k=0; k<NX; k++) {
             for (j=0; j<nprocs; j++) {
                 if (buf[i*nprocs*NX+k*nprocs+j] != j+10) {
-                    printf("Error at line %d: expected buffer[%d]=%d but got %d\n",
-                           __LINE__,i*nprocs*NX+k*nprocs+j, j+10, buf[i*nprocs*NX+k*nprocs+j]);
+                    printf("Error at line %d in %s: expected buffer[%d]=%d but got %d\n",
+                           __LINE__,__FILE__,i*nprocs*NX+k*nprocs+j, j+10, buf[i*nprocs*NX+k*nprocs+j]);
                     nerrs++;
                 }
             }
@@ -263,7 +257,7 @@ int main(int argc, char **argv)
     }
 
     err = ncmpi_close(ncid);
-    if (err != NC_NOERR) HANDLE_ERROR(err)
+    CHECK_ERR
 
     free(buf);
 
@@ -277,7 +271,6 @@ int main(int argc, char **argv)
                    sum_size);
     }
 
-fn_exit:
     MPI_Allreduce(MPI_IN_PLACE, &nerrs, 1, MPI_INT, MPI_SUM, MPI_COMM_WORLD);
     if (rank == 0) {
         if (nerrs) printf(FAIL_STR,nerrs);
@@ -285,5 +278,5 @@ fn_exit:
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
