@@ -2,7 +2,7 @@
  *  Copyright (C) 2014, Northwestern University and Argonne National Laboratory
  *  See COPYRIGHT notice in top-level directory.
  *
- *  $Id: one_record.c 2744 2016-12-28 16:25:22Z wkliao $
+ *  $Id: one_record.c 3341 2017-08-25 22:29:08Z wkliao $
  */
 
 /*
@@ -23,9 +23,6 @@
 
 #include <testutils.h>
 
-#define ERRCODE 2
-#define ERR if (err != NC_NOERR) {printf("Error at line %d: err=%d %s\n", __LINE__, err, ncmpi_strerror(err));}
-
 #define STR_LEN 19
 #define NUM_VALS 2
 
@@ -46,7 +43,7 @@ int main(int argc, char **argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -62,16 +59,16 @@ int main(int argc, char **argv)
     strcpy(data[1], "2005-04-11_13:00:00");
 
     cmode = NC_CLOBBER;
-    err  = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid); ERR
+    err  = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid); CHECK_ERR
 
-    err = ncmpi_def_dim(ncid, "time", NC_UNLIMITED, dimids); ERR
-    err = ncmpi_def_dim(ncid, "text_dim", STR_LEN, &dimids[1]); ERR
+    err = ncmpi_def_dim(ncid, "time", NC_UNLIMITED, dimids); CHECK_ERR
+    err = ncmpi_def_dim(ncid, "text_dim", STR_LEN, &dimids[1]); CHECK_ERR
 
     /* create ONLY one record variable of type NC_CHAR and make sure each
      * record is of size not aligned with 4-byte boundary.
      */
-    err = ncmpi_def_var(ncid, "text_var", NC_CHAR, 2, dimids, &varid); ERR
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_def_var(ncid, "text_var", NC_CHAR, 2, dimids, &varid); CHECK_ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     /* Write some records of var data. */
     count[0] = 1;
@@ -80,22 +77,28 @@ int main(int argc, char **argv)
     start[1] = 0;
     for (i=0; i<NUM_VALS; i++) {
         err = ncmpi_put_vara_text_all(ncid, varid, start, count, data[start[0]]);
-        ERR
+        CHECK_ERR
         start[0]++;
     }
 
+    err = ncmpi_close(ncid); CHECK_ERR
+
+    err  = ncmpi_open(MPI_COMM_WORLD, filename, NC_NOWRITE, MPI_INFO_NULL, &ncid); CHECK_ERR
+
+    err = ncmpi_inq_varid(ncid, "text_var", &varid); CHECK_ERR
+
     /* read the entire data back */
-    err = ncmpi_get_var_text_all(ncid, varid, data_in); ERR
+    err = ncmpi_get_var_text_all(ncid, varid, data_in); CHECK_ERR
 
     /* check the contents */
     for (i=0; i<NUM_VALS; i++)
       if (strncmp(data[i], data_in+i*STR_LEN, STR_LEN)) {
-          printf("Error: expecting %s but got %s\n", data[i],data_in+i*STR_LEN);
+          printf("Error at line %d in %s: expecting %s but got %s\n",
+          __LINE__,__FILE__,data[i],data_in+i*STR_LEN);
           nerrs++;
       }
 
-    err = ncmpi_close(ncid);
-    ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     /* check if PnetCDF freed all internal malloc */
     MPI_Offset malloc_size, sum_size;
@@ -114,7 +117,6 @@ int main(int argc, char **argv)
     }
 
     MPI_Finalize();
-
-    return nerrs;
+    return (nerrs > 0);
 }
 
