@@ -3,7 +3,7 @@
 !   Laboratory
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: put_parameter.f 2638 2016-11-18 14:51:02Z wkliao $
+! $Id: put_parameter.f 3341 2017-08-25 22:29:08Z wkliao $
 
 ! This example tests PnetCDF's avoiding in-place Endianness byte swap when
 ! the user's write buffer is immutable, i.e. defined as PARAMETER.
@@ -63,7 +63,7 @@
               write(6,*) message(1:XTRIM(message)), nfmpi_strerror(err)
               msg = '*** TESTING F77 put_parameter.f for immutable put '
               call pass_fail(1, msg)
-              call MPI_Abort(MPI_COMM_WORLD, -1, err)
+              STOP 2
           end if
       end ! subroutine check
 
@@ -164,5 +164,7 @@
           endif
 
  999      call MPI_Finalize(ierr)
+          if (nerrs .GT. 0) stop 2
+
       end ! program main
 
