@@ -36,9 +36,6 @@
 
 #include <testutils.h>
 
-#define ERR if (err!=NC_NOERR) {printf("Error at line %d: %s\n",__LINE__,ncmpi_strerror(err));nerrs++;}
-#define EXPECT_ERR if (err != NC_ERANGE) {printf("Error at line %d: expecting NC_ERANGE, but got %d\n",__LINE__,err);nerrs++;}
-
 static
 int test_cdf2(char *filename)
 {
@@ -47,7 +44,7 @@ int test_cdf2(char *filename)
     signed char sc[1];
     int si[1];
 
-    err = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER, MPI_INFO_NULL, &ncid); ERR
+    err = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER, MPI_INFO_NULL, &ncid); CHECK_ERR
 
     /* for CDF-1 and CDF-2, a special case is made: there is no NC_ERANGE
      * error can occur converting between NC_BYTE and unsigned char.
@@ -56,31 +53,31 @@ int test_cdf2(char *filename)
      * all unsigned APIs. In CDF-2, there is only one unsigned API, _uchar.
      */
     uc[0] = 255;
-    err = ncmpi_put_att_uchar(ncid, NC_GLOBAL, "att1", NC_BYTE, 1, uc); ERR
+    err = ncmpi_put_att_uchar(ncid, NC_GLOBAL, "att1", NC_BYTE, 1, uc); CHECK_ERR
     uc[0] = 0; /* initialize with a number that is not 0 */
-    err = ncmpi_get_att_uchar(ncid, NC_GLOBAL, "att1", uc); ERR
+    err = ncmpi_get_att_uchar(ncid, NC_GLOBAL, "att1", uc); CHECK_ERR
     if (uc[0] != 255) {
         printf("Error at line %d: unexpected read value %d (expecting 255)\n",__LINE__,(int)uc[0]);
         nerrs++;
     }
     sc[0] = 3; /* initialize with a number that is not -1 or -0 */
     /* No NC_ERANGE as the internal and external types are considered the same */
-    err = ncmpi_get_att_schar(ncid, NC_GLOBAL, "att1", sc); ERR
+    err = ncmpi_get_att_schar(ncid, NC_GLOBAL, "att1", sc); CHECK_ERR
     if (   sc[0] != -1     /* 2-complement bit representation */
         && sc[0] != -0) {  /* 1-complement bit representation */
         printf("Error at line %d: unexpected read value %d (expecting 255)\n",__LINE__,(int)uc[0]);
         nerrs++;
     }
 
-    err = ncmpi_def_dim(ncid, "x", 1, &dimid); ERR
-    err = ncmpi_def_var(ncid, "var_byte", NC_BYTE, 1, &dimid, &vid); ERR
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_def_dim(ncid, "x", 1, &dimid); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var_byte", NC_BYTE, 1, &dimid, &vid); CHECK_ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     /* No NC_ERANGE should be returned for CDF-1 and 2 */
     uc[0] = 255;
-    err = ncmpi_put_var_uchar_all(ncid, vid, uc); ERR
+    err = ncmpi_put_var_uchar_all(ncid, vid, uc); CHECK_ERR
     uc[0] = 3; /* initialize with a number that is not -1 or -0 */
-    err = ncmpi_get_var_uchar_all(ncid, vid, uc); ERR
+    err = ncmpi_get_var_uchar_all(ncid, vid, uc); CHECK_ERR
     if (uc[0] != 255) {
         printf("Error at line %d: unexpected read value %d (expecting 255)\n",__LINE__,(int)uc[0]);
         nerrs++;
@@ -88,9 +85,9 @@ int test_cdf2(char *filename)
 
     /* No NC_ERANGE should be returned for CDF-1 and 2 */
     sc[0] = -128;
-    err = ncmpi_put_var_schar_all(ncid, vid, sc); ERR
+    err = ncmpi_put_var_schar_all(ncid, vid, sc); CHECK_ERR
     sc[0] = 0;
-    err = ncmpi_get_var_schar_all(ncid, vid, sc); ERR
+    err = ncmpi_get_var_schar_all(ncid, vid, sc); CHECK_ERR
     if (sc[0] != -128) {
         printf("Error at line %d: unexpected read value %d (expecting -128)\n",__LINE__,(int)sc[0]);
         nerrs++;
@@ -98,7 +95,7 @@ int test_cdf2(char *filename)
 
     /* expect NC_ERANGE */
     si[0] = -129;
-    err = ncmpi_put_var_int_all(ncid, vid, si); EXPECT_ERR
+    err = ncmpi_put_var_int_all(ncid, vid, si); EXP_ERR(NC_ERANGE)
     if (si[0] != -129) { /* check if put buffer content is altered */
         printf("Error at line %d: put buffer content altered %d (expecting -128)\n",__LINE__,si[0]);
         nerrs++;
@@ -106,7 +103,7 @@ int test_cdf2(char *filename)
 
     /* expect NC_ERANGE */
     si[0] = 256;
-    err = ncmpi_put_var_int_all(ncid, vid, si); EXPECT_ERR
+    err = ncmpi_put_var_int_all(ncid, vid, si); EXP_ERR(NC_ERANGE)
     if (si[0] != 256) { /* check if put buffer content is altered */
         printf("Error at line %d: put buffer content altered %d (expecting 256)\n",__LINE__,si[0]);
         nerrs++;
@@ -114,15 +111,15 @@ int test_cdf2(char *filename)
 
     /* expect no error */
     si[0] = -128;
-    err = ncmpi_put_var_int_all(ncid, vid, si); ERR
+    err = ncmpi_put_var_int_all(ncid, vid, si); CHECK_ERR
     si[0] = 0;
-    err = ncmpi_get_var_int_all(ncid, vid, si); ERR
+    err = ncmpi_get_var_int_all(ncid, vid, si); CHECK_ERR
     if (si[0] != -128) {
         printf("Error at line %d: unexpected read value %d (expecting -128)\n",__LINE__,si[0]);
         nerrs++;
     }
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -134,7 +131,7 @@ int test_cdf5(char *filename)
     unsigned char uc[1];
     signed char sc[1];
 
-    err = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER|NC_64BIT_DATA, MPI_INFO_NULL, &ncid); ERR
+    err = ncmpi_create(MPI_COMM_WORLD, filename, NC_CLOBBER|NC_64BIT_DATA, MPI_INFO_NULL, &ncid); CHECK_ERR
 
     /* CDF-5 considers NC_BYTE a signed 1-byte integer and NC_UBYTE an
      * unsigned 1-byte integer. The special case in CDF-2 for skipping
@@ -142,37 +139,37 @@ int test_cdf5(char *filename)
      * char is no longer held.
      */
     uc[0] = 255;
-    err = ncmpi_put_att_uchar(ncid, NC_GLOBAL, "att1", NC_UBYTE, 1, uc); ERR
+    err = ncmpi_put_att_uchar(ncid, NC_GLOBAL, "att1", NC_UBYTE, 1, uc); CHECK_ERR
 
     /* in CDF-5, get 255 to a schar buffer should result in NC_ERANGE */
-    err = ncmpi_get_att_schar(ncid, NC_GLOBAL, "att1", sc); EXPECT_ERR
+    err = ncmpi_get_att_schar(ncid, NC_GLOBAL, "att1", sc); EXP_ERR(NC_ERANGE)
 
     sc[0] = -1; /* a value should cause NC_ERANGE */
-    err = ncmpi_put_att_schar(ncid, NC_GLOBAL, "att2", NC_UBYTE, 1, sc); EXPECT_ERR
+    err = ncmpi_put_att_schar(ncid, NC_GLOBAL, "att2", NC_UBYTE, 1, sc); EXP_ERR(NC_ERANGE)
 
-    err = ncmpi_def_dim(ncid, "x", 1, &dimid); ERR
-    err = ncmpi_def_var(ncid, "var_ubyte", NC_UBYTE, 1, &dimid, &uc_vid); ERR
-    err = ncmpi_def_var(ncid, "var_byte",  NC_BYTE,  1, &dimid, &sc_vid); ERR
-    err = ncmpi_enddef(ncid); ERR
+    err = ncmpi_def_dim(ncid, "x", 1, &dimid); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var_ubyte", NC_UBYTE, 1, &dimid, &uc_vid); CHECK_ERR
+    err = ncmpi_def_var(ncid, "var_byte",  NC_BYTE,  1, &dimid, &sc_vid); CHECK_ERR
+    err = ncmpi_enddef(ncid); CHECK_ERR
 
     uc[0] = 255;
-    err = ncmpi_put_var_uchar_all(ncid, uc_vid, uc); ERR
+    err = ncmpi_put_var_uchar_all(ncid, uc_vid, uc); CHECK_ERR
 
     /* in CDF-5, get 255 to an schar should result in NC_ERANGE */
-    err = ncmpi_get_var_schar_all(ncid, uc_vid, sc); EXPECT_ERR
+    err = ncmpi_get_var_schar_all(ncid, uc_vid, sc); EXP_ERR(NC_ERANGE)
 
     sc[0] = -1; /* in CDF-5, put -1 to an uchar should result in NC_ERANGE */
-    err = ncmpi_put_var_schar_all(ncid, uc_vid, sc); EXPECT_ERR
+    err = ncmpi_put_var_schar_all(ncid, uc_vid, sc); EXP_ERR(NC_ERANGE)
 
     uc[0] = 255; /* in CDF-5, put 255 to a schar should result in NC_ERANGE */
-    err = ncmpi_put_var_uchar_all(ncid, sc_vid, uc); EXPECT_ERR
+    err = ncmpi_put_var_uchar_all(ncid, sc_vid, uc); EXP_ERR(NC_ERANGE)
 
     sc[0] = -1;
-    err = ncmpi_put_var_schar_all(ncid, sc_vid, sc); ERR
+    err = ncmpi_put_var_schar_all(ncid, sc_vid, sc); CHECK_ERR
     uc[0] = 0; /* in CDF-5, get -1 to an uchar should result in NC_ERANGE */
-    err = ncmpi_get_var_uchar_all(ncid, sc_vid, uc); EXPECT_ERR
+    err = ncmpi_get_var_uchar_all(ncid, sc_vid, uc); EXP_ERR(NC_ERANGE)
 
-    err = ncmpi_close(ncid); ERR
+    err = ncmpi_close(ncid); CHECK_ERR
 
     return nerrs;
 }
@@ -188,7 +185,7 @@ int main(int argc, char* argv[])
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -221,6 +218,5 @@ int main(int argc, char* argv[])
     }
 
     MPI_Finalize();
-
-    return 0;
+    return (nerrs > 0);
 }
