@@ -2,18 +2,18 @@
 !   Copyright (C) 2014, Northwestern University and Argonne National Laboratory
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: test_vardf90.f90 2639 2016-11-18 15:06:10Z wkliao $
+! $Id: test_vardf90.f90 3422 2017-09-25 05:42:52Z wkliao $
 
 !
 ! This program tests the vard API.
 ! The write buffer is a 2D array of size NX x NY
 ! The MPI data type for the buffer is defined by swapping the 1st and 2nd
-! rows of the array using a butype constructed by MPI_Type_create_hindex().
+! rows of the array using a buftype constructed by MPI_Type_create_hindex().
 ! It also writes a fixed-size variable using a buftype constructed by
 ! MPI_Type_create_subarray(). Both record and foxed-size variables are read
 ! back using various filetypes and buftypes and check the contents.
 !
-! The expected reults from the output file contents are:
+! The expected results from the output file contents are:
 ! (when running on 1 MPI process)
 !
 !  % ncmpidump testfile.nc
@@ -370,5 +370,7 @@
           endif
 
  999      call MPI_Finalize(ierr)
+          if (nerrs .GT. 0) stop 2
+
       end program main
 
