@@ -4,7 +4,7 @@
  *  See COPYRIGHT notice in top-level directory.
  *
  *********************************************************************/
-/* $Id: varn_int.c 2744 2016-12-28 16:25:22Z wkliao $ */
+/* $Id: varn_int.c 3341 2017-08-25 22:29:08Z wkliao $ */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * This example tests using a single call of ncmpi_put_varn_int_all() to
@@ -54,8 +54,6 @@
 #define NX 10
 #define NDIMS 2
 
-#define ERR {if(err!=NC_NOERR){printf("Error at %s line=%d: %s\n", __FILE__,__LINE__, ncmpi_strerror(err)); nerrs++;}}
-
 static
 int check_contents_for_fail(int *buffer)
 {
@@ -103,7 +101,7 @@ int main(int argc, char** argv)
     if (argc > 2) {
         if (!rank) printf("Usage: %s [filename]\n",argv[0]);
         MPI_Finalize();
-        return 0;
+        return 1;
     }
     if (argc == 2) snprintf(filename, 256, "%s", argv[1]);
     else           strcpy(filename, "testfile.nc");
@@ -124,21 +122,21 @@ int main(int argc, char** argv)
     /* create a new file for writing ----------------------------------------*/
     cmode = NC_CLOBBER | NC_64BIT_DATA;
     err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, MPI_INFO_NULL, &ncid);
-    ERR
+    CHECK_ERR
 
     /* create a global array of size NY * NX */
     err = ncmpi_def_dim(ncid, "Y", NY, &dimid[0]);
-    ERR
+    CHECK_ERR
     err = ncmpi_def_dim(ncid, "X", NX, &dimid[1]);
-    ERR
+    CHECK_ERR
     err = ncmpi_def_var(ncid, "var", NC_INT, NDIMS, dimid, &varid[0]);
-    ERR
+    CHECK_ERR
     err = ncmpi_def_dim(ncid, "REC_DIM", NC_UNLIMITED, &dimid[0]);
-    ERR
+    CHECK_ERR
     err = ncmpi_def_var(ncid, "rec_var", NC_INT, NDIMS, dimid, &varid[1]);
-    ERR
+    CHECK_ERR
     err = ncmpi_enddef(ncid);
-    ERR
+    CHECK_ERR
 
     /* pick arbitrary numbers of requests for 4 processes */
     num_reqs = 0;
@@ -222,20 +220,17 @@ int main(int argc, char** argv)
 
     /* check error code: NC_ENULLSTART */
     err = ncmpi_put_varn_int_all(ncid, varid[0], 1, NULL, NULL, NULL);
-    if (err != NC_ENULLSTART) {
-        printf("expecting error code NC_ENULLSTART but got %s\n",nc_err_code_name(err));
-        nerrs++;
-    }
+    EXP_ERR(NC_ENULLSTART)
 
     /* write using varn API */
     err = ncmpi_put_varn_int_all(ncid, varid[0], num_reqs, starts, counts, buffer);
-    ERR
+    CHECK_ERR
 
     /* check if user put buffer contents altered */
     for (i=0; i<w_len; i++) {
         if (buffer[i] != rank+10) {
-            printf("Error: user put buffer[%d] altered from %d to %d\n",
-                   i, rank+10, buffer[i]);
+            printf("Error at line %d in %s: user put buffer[%d] altered from %d to %d\n",
+                   __LINE__,__FILE__,i, rank+10, buffer[i]);
             nerrs++;
         }
     }
@@ -244,7 +239,7 @@ int main(int argc, char** argv)
     /* read back and check contents */
     memset(r_buffer, 0, NY*NX*sizeof(int));
     err = ncmpi_get_var_int_all(ncid, varid[0], r_buffer);
-    ERR
+    CHECK_ERR
     nerrs += check_contents_for_fail(r_buffer);
 
     /* permute write order */
@@ -255,13 +250,13 @@ int main(int argc, char** argv)
 
     /* write using varn API */
     err = ncmpi_put_varn_int_all(ncid, varid[1], num_reqs, starts, counts, buffer);
-    ERR
+    CHECK_ERR
 
     /* check if user put buffer contents altered */
     for (i=0; i<w_len; i++) {
         if (buffer[i] != rank+10) {
-            printf("Error: user put buffer[%d] altered from %d to %d\n",
-                   i, rank+10, buffer[i]);
+            printf("Error at line %d in %s: user put buffer[%d] altered from %d to %d\n",
+                   __LINE__,__FILE__,i, rank+10, buffer[i]);
             nerrs++;
         }
     }
@@ -269,18 +264,18 @@ int main(int argc, char** argv)
     /* read back using get_var API and check contents */
     memset(r_buffer, 0, NY*NX*sizeof(int));
     err = ncmpi_get_var_int_all(ncid, varid[1], r_buffer);
-    ERR
+    CHECK_ERR
     nerrs += check_contents_for_fail(r_buffer);
 
     /* read back using get_varn API and check contents */
     for (i=0; i<w_len; i++) buffer[i] = -1;
     err = ncmpi_get_varn_int_all(ncid, varid[0], num_reqs, starts, counts, buffer);
-    ERR
+    CHECK_ERR
 
     for (i=0; i<w_len; i++) {
         if (buffer[i] != rank+10) {
-            printf("Error at line %d: expecting buffer[%d]=%d but got %d\n",
-                   __LINE__,i,rank+10,buffer[i]);
+            printf("Error at line %d in %s: expecting buffer[%d]=%d but got %d\n",
+                   __LINE__,__FILE__,i,rank+10,buffer[i]);
             nerrs++;
         }
     }
@@ -293,24 +288,24 @@ int main(int argc, char** argv)
     buffer = (int*) malloc(w_len * 2 * sizeof(int));
     for (i=0; i<2*w_len; i++) buffer[i] = -1;
     err = ncmpi_get_varn_all(ncid, varid[0], num_reqs, starts, counts, buffer, 1, buftype);
-    ERR
+    CHECK_ERR
     MPI_Type_free(&buftype);
 
     for (i=0; i<w_len*2; i++) {
         if (i%2 && buffer[i] != -1) {
-            printf("Error at line %d: expecting buffer[%d]=-1 but got %d\n",
-                   __LINE__,i,buffer[i]);
+            printf("Error at line %d in %s: expecting buffer[%d]=-1 but got %d\n",
+                   __LINE__,__FILE__,i,buffer[i]);
             nerrs++;
         }
         if (i%2 == 0 && buffer[i] != rank+10) {
-            printf("Error at line %d: expecting buffer[%d]=%d but got %d\n",
-                   __LINE__,i,rank+10,buffer[i]);
+            printf("Error at line %d in %s: expecting buffer[%d]=%d but got %d\n",
+                   __LINE__,__FILE__,i,rank+10,buffer[i]);
             nerrs++;
         }
     }
 
     err = ncmpi_close(ncid);
-    ERR
+    CHECK_ERR
 
     free(buffer);
     free(r_buffer);
@@ -336,6 +331,6 @@ int main(int argc, char** argv)
     }
 
     MPI_Finalize();
-    return 0;
+    return (nerrs > 0);
 }
 
