@@ -2,7 +2,7 @@
 !   Copyright (C) 2013, Northwestern University
 !   See COPYRIGHT notice in top-level directory.
 !
-! $Id: varn_intf.f 2638 2016-11-18 14:51:02Z wkliao $
+! $Id: varn_intf.f 3341 2017-08-25 22:29:08Z wkliao $
 
 ! This example shows how to use a single call of nfmpi_put_varn_int_all() to
 ! write a sequence of requests with arbitrary array indices and lengths.
@@ -69,7 +69,7 @@
               write(6,*) message(1:XTRIM(message)), nfmpi_strerror(err)
               msg = '*** TESTING F77 varn_intf.f for varn API '
               call pass_fail(1, msg)
-              call MPI_Abort(MPI_COMM_WORLD, -1, err)
+              STOP 2
           end if
       end ! subroutine check
 
@@ -287,5 +287,7 @@
           endif
 
  999      call MPI_Finalize(ierr)
+          if (nerrs .GT. 0) stop 2
+
       end ! program main
 
