@@ -2,7 +2,7 @@
 !  Copyright (C) 2012, Northwestern University and Argonne National Laboratory
 !  See COPYRIGHT notice in top-level directory.
 !
-! $Id: varn_real.f90 2638 2016-11-18 14:51:02Z wkliao $
+! $Id: varn_real.f90 3341 2017-08-25 22:29:08Z wkliao $
 
 !
 ! This example shows how to use a single call of nf90mpi_put_varn_all()
@@ -45,6 +45,7 @@
               msg = '*** TESTING F90 varn_real.f90 for varn API '
               call pass_fail(1, msg)
               ! call MPI_Abort(MPI_COMM_WORLD, -1, err)
+              STOP 2
           end if
       end subroutine check
 
@@ -296,6 +297,7 @@
           endif
 
  999      call MPI_Finalize(ierr)
+          if (nerrs .GT. 0) stop 2
 
       end program
 
